@@ -80,48 +80,6 @@ public class SocketWindowWordCountITCase extends AbstractTestBase {
         }
     }
 
-    @Test
-    public void testScalaProgram() throws Exception {
-        InetAddress localhost = InetAddress.getByName("localhost");
-
-        // suppress sysout messages from this example
-        final PrintStream originalSysout = System.out;
-        final PrintStream originalSyserr = System.err;
-
-        final ByteArrayOutputStream errorMessages = new ByteArrayOutputStream();
-
-        System.setOut(new PrintStream(new NullStream()));
-        System.setErr(new PrintStream(errorMessages));
-
-        try {
-            try (ServerSocket server = new ServerSocket(0, 10, localhost)) {
-
-                final ServerThread serverThread = new ServerThread(server);
-                serverThread.setDaemon(true);
-                serverThread.start();
-
-                final int serverPort = server.getLocalPort();
-
-                org.apache.flink.streaming.scala.examples.socket.SocketWindowWordCount.main(
-                        new String[] {"--port", String.valueOf(serverPort)});
-
-                if (errorMessages.size() != 0) {
-                    fail(
-                            "Found error message: "
-                                    + new String(
-                                            errorMessages.toByteArray(),
-                                            ConfigConstants.DEFAULT_CHARSET));
-                }
-
-                serverThread.join();
-                serverThread.checkError();
-            }
-        } finally {
-            System.setOut(originalSysout);
-            System.setErr(originalSyserr);
-        }
-    }
-
     // ------------------------------------------------------------------------
 
     private static class ServerThread extends Thread {
