@@ -23,8 +23,10 @@ import org.apache.flink.runtime.checkpoint.CheckpointMetaData;
 import org.apache.flink.runtime.checkpoint.CheckpointMetrics;
 import org.apache.flink.runtime.checkpoint.InflightDataRescalingDescriptor;
 import org.apache.flink.runtime.checkpoint.PrioritizedOperatorSubtaskState;
+import org.apache.flink.runtime.checkpoint.SubTaskInitializationMetrics;
 import org.apache.flink.runtime.checkpoint.TaskStateSnapshot;
 import org.apache.flink.runtime.checkpoint.channel.SequentialChannelStateReader;
+import org.apache.flink.runtime.checkpoint.filemerging.FileMergingSnapshotManager;
 import org.apache.flink.runtime.jobgraph.OperatorID;
 import org.apache.flink.runtime.state.LocalRecoveryConfig;
 import org.apache.flink.runtime.state.TaskStateManager;
@@ -53,6 +55,10 @@ final class SavepointTaskStateManager implements TaskStateManager {
         this.prioritizedOperatorSubtaskState = prioritizedOperatorSubtaskState;
     }
 
+    @Override
+    public void reportInitializationMetrics(
+            SubTaskInitializationMetrics subTaskInitializationMetrics) {}
+
     @Override
     public void reportTaskStateSnapshots(
             @Nonnull CheckpointMetaData checkpointMetaData,
@@ -114,6 +120,12 @@ final class SavepointTaskStateManager implements TaskStateManager {
         return null;
     }
 
+    @Nullable
+    @Override
+    public FileMergingSnapshotManager getFileMergingSnapshotManager() {
+        return null;
+    }
+
     @Override
     public void notifyCheckpointComplete(long checkpointId) {
         throw new UnsupportedOperationException(MSG);
