@@ -25,11 +25,11 @@ import org.apache.flink.runtime.jobgraph.OperatorID;
 import org.apache.flink.state.api.BootstrapTransformation;
 import org.apache.flink.state.api.runtime.BootstrapTransformationWithID;
 import org.apache.flink.state.api.runtime.OperatorIDGenerator;
+import org.apache.flink.util.CollectionUtil;
 import org.apache.flink.util.Preconditions;
 
 import java.io.IOException;
 import java.util.Collection;
-import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
 import java.util.stream.Collectors;
@@ -61,7 +61,7 @@ public class SavepointMetadata {
 
         this.masterStates = Preconditions.checkNotNull(masterStates);
 
-        this.operatorStateIndex = new HashMap<>(initialStates.size());
+        this.operatorStateIndex = CollectionUtil.newHashMapWithExpectedSize(initialStates.size());
         initialStates.forEach(
                 existingState ->
                         operatorStateIndex.put(
