@@ -102,16 +102,22 @@ public interface BlobWriter {
         if (serializedValue.getByteArray().length < blobWriter.getMinOffloadingSize()) {
             return Either.Left(serializedValue);
         } else {
-            try {
-                final PermanentBlobKey permanentBlobKey =
-                        blobWriter.putPermanent(jobId, serializedValue.getByteArray());
+            return offloadWithException(serializedValue, jobId, blobWriter);
+        }
+    }
 
-                return Either.Right(permanentBlobKey);
-            } catch (IOException e) {
-                LOG.warn("Failed to offload value for job {} to BLOB store.", jobId, e);
-
-                return Either.Left(serializedValue);
-            }
+    static <T> Either<SerializedValue<T>, PermanentBlobKey> offloadWithException(
+            SerializedValue<T> serializedValue, JobID jobId, BlobWriter blobWriter) {
+        Preconditions.checkNotNull(serializedValue);
+        Preconditions.checkNotNull(jobId);
+        Preconditions.checkNotNull(blobWriter);
+        try {
+            final PermanentBlobKey permanentBlobKey =
+                    blobWriter.putPermanent(jobId, serializedValue.getByteArray());
+            return Either.Right(permanentBlobKey);
+        } catch (IOException e) {
+            LOG.warn("Failed to offload value for job {} to BLOB store.", jobId, e);
+            return Either.Left(serializedValue);
         }
     }
 }
