@@ -31,13 +31,12 @@ import org.apache.flink.runtime.io.network.partition.hybrid.tiered.storage.Tiere
 import org.apache.flink.runtime.shuffle.PartitionDescriptorBuilder;
 import org.apache.flink.runtime.util.EnvironmentInformation;
 import org.apache.flink.runtime.util.NettyShuffleDescriptorBuilder;
-import org.apache.flink.util.TestLoggerExtension;
 
 import org.junit.jupiter.api.AfterAll;
 import org.junit.jupiter.api.BeforeAll;
 import org.junit.jupiter.api.Test;
-import org.junit.jupiter.api.extension.ExtendWith;
 
+import java.io.IOException;
 import java.util.Optional;
 import java.util.concurrent.Executors;
 
@@ -45,7 +44,6 @@ import static org.assertj.core.api.Assertions.assertThat;
 
 /** Tests for the {@link ResultPartitionFactory}. */
 @SuppressWarnings("StaticVariableUsedBeforeInitialization")
-@ExtendWith(TestLoggerExtension.class)
 class ResultPartitionFactoryTest {
 
     private static final String tempDir = EnvironmentInformation.getTemporaryFileDirectory();
@@ -64,7 +62,7 @@ class ResultPartitionFactoryTest {
     }
 
     @Test
-    void testBoundedBlockingSubpartitionsCreated() {
+    void testBoundedBlockingSubpartitionsCreated() throws IOException {
         final BoundedBlockingResultPartition resultPartition =
                 (BoundedBlockingResultPartition)
                         createResultPartition(ResultPartitionType.BLOCKING);
@@ -73,7 +71,7 @@ class ResultPartitionFactoryTest {
     }
 
     @Test
-    void testPipelinedSubpartitionsCreated() {
+    void testPipelinedSubpartitionsCreated() throws IOException {
         final PipelinedResultPartition resultPartition =
                 (PipelinedResultPartition) createResultPartition(ResultPartitionType.PIPELINED);
         assertThat(resultPartition.subpartitions)
@@ -81,26 +79,26 @@ class ResultPartitionFactoryTest {
     }
 
     @Test
-    void testSortMergePartitionCreated() {
+    void testSortMergePartitionCreated() throws IOException {
         ResultPartition resultPartition = createResultPartition(ResultPartitionType.BLOCKING, 1);
         assertThat(resultPartition).isInstanceOf(SortMergeResultPartition.class);
     }
 
     @Test
-    void testHybridFullResultPartitionOfLegacyModeCreated() {
+    void testHybridFullResultPartitionOfLegacyModeCreated() throws IOException {
         ResultPartition resultPartition = createResultPartition(ResultPartitionType.HYBRID_FULL);
         assertThat(resultPartition).isInstanceOf(HsResultPartition.class);
     }
 
     @Test
-    void testHybridSelectiveResultPartitionOfLegacyModeCreated() {
+    void testHybridSelectiveResultPartitionOfLegacyModeCreated() throws IOException {
         ResultPartition resultPartition =
                 createResultPartition(ResultPartitionType.HYBRID_SELECTIVE);
         assertThat(resultPartition).isInstanceOf(HsResultPartition.class);
     }
 
     @Test
-    void testHybridFullResultPartitionOfNewModeCreated() {
+    void testHybridFullResultPartitionOfNewModeCreated() throws IOException {
         ResultPartition resultPartition =
                 createResultPartition(
                         ResultPartitionType.HYBRID_FULL, createTieredResultPartitionFactory());
@@ -108,7 +106,7 @@ class ResultPartitionFactoryTest {
     }
 
     @Test
-    void testHybridSelectiveResultPartitionOfNewModeCreated() {
+    void testHybridSelectiveResultPartitionOfNewModeCreated() throws IOException {
         ResultPartition resultPartition =
                 createResultPartition(
                         ResultPartitionType.HYBRID_SELECTIVE, createTieredResultPartitionFactory());
@@ -116,7 +114,7 @@ class ResultPartitionFactoryTest {
     }
 
     @Test
-    void testNoReleaseOnConsumptionForBoundedBlockingPartition() {
+    void testNoReleaseOnConsumptionForBoundedBlockingPartition() throws IOException {
         final ResultPartition resultPartition = createResultPartition(ResultPartitionType.BLOCKING);
 
         resultPartition.onConsumedSubpartition(0);
@@ -125,7 +123,7 @@ class ResultPartitionFactoryTest {
     }
 
     @Test
-    void testNoReleaseOnConsumptionForSortMergePartition() {
+    void testNoReleaseOnConsumptionForSortMergePartition() throws IOException {
         final ResultPartition resultPartition =
                 createResultPartition(ResultPartitionType.BLOCKING, 1);
 
@@ -135,7 +133,7 @@ class ResultPartitionFactoryTest {
     }
 
     @Test
-    void testNoReleaseOnConsumptionForHybridFullPartitionOfLegacyMode() {
+    void testNoReleaseOnConsumptionForHybridFullPartitionOfLegacyMode() throws IOException {
         final ResultPartition resultPartition =
                 createResultPartition(ResultPartitionType.HYBRID_FULL);
 
@@ -145,7 +143,7 @@ class ResultPartitionFactoryTest {
     }
 
     @Test
-    void testNoReleaseOnConsumptionForHybridSelectivePartitionOfLegacyMode() {
+    void testNoReleaseOnConsumptionForHybridSelectivePartitionOfLegacyMode() throws IOException {
         final ResultPartition resultPartition =
                 createResultPartition(ResultPartitionType.HYBRID_SELECTIVE);
 
@@ -155,7 +153,7 @@ class ResultPartitionFactoryTest {
     }
 
     @Test
-    void testNoReleaseOnConsumptionForHybridFullPartitionOfNewMode() {
+    void testNoReleaseOnConsumptionForHybridFullPartitionOfNewMode() throws IOException {
         ResultPartition resultPartition =
                 createResultPartition(
                         ResultPartitionType.HYBRID_FULL, createTieredResultPartitionFactory());
@@ -166,7 +164,7 @@ class ResultPartitionFactoryTest {
     }
 
     @Test
-    void testNoReleaseOnConsumptionForHybridSelectivePartitionOfNewMode() {
+    void testNoReleaseOnConsumptionForHybridSelectivePartitionOfNewMode() throws IOException {
         ResultPartition resultPartition =
                 createResultPartition(
                         ResultPartitionType.HYBRID_SELECTIVE, createTieredResultPartitionFactory());
@@ -176,18 +174,19 @@ class ResultPartitionFactoryTest {
         assertThat(resultPartition.isReleased()).isFalse();
     }
 
-    private static ResultPartition createResultPartition(ResultPartitionType partitionType) {
+    private static ResultPartition createResultPartition(ResultPartitionType partitionType)
+            throws IOException {
         return createResultPartition(partitionType, Integer.MAX_VALUE, false, Optional.empty());
     }
 
     private static ResultPartition createResultPartition(
-            ResultPartitionType partitionType,
-            Optional<TieredResultPartitionFactory> tieredStorage) {
+            ResultPartitionType partitionType, Optional<TieredResultPartitionFactory> tieredStorage)
+            throws IOException {
         return createResultPartition(partitionType, Integer.MAX_VALUE, false, tieredStorage);
     }
 
     private static ResultPartition createResultPartition(
-            ResultPartitionType partitionType, int sortShuffleMinParallelism) {
+            ResultPartitionType partitionType, int sortShuffleMinParallelism) throws IOException {
         return createResultPartition(
                 partitionType, sortShuffleMinParallelism, false, Optional.empty());
     }
@@ -196,7 +195,8 @@ class ResultPartitionFactoryTest {
             ResultPartitionType partitionType,
             int sortShuffleMinParallelism,
             boolean isBroadcast,
-            Optional<TieredResultPartitionFactory> tieredStorage) {
+            Optional<TieredResultPartitionFactory> tieredStorage)
+            throws IOException {
         final ResultPartitionManager manager = new ResultPartitionManager();
 
         final ResultPartitionFactory factory =
