@@ -18,6 +18,7 @@
 
 package org.apache.flink.runtime.io.network.partition.consumer;
 
+import org.apache.flink.api.java.tuple.Tuple2;
 import org.apache.flink.core.memory.MemorySegment;
 import org.apache.flink.core.memory.MemorySegmentFactory;
 import org.apache.flink.metrics.groups.UnregisteredMetricsGroup;
@@ -60,8 +61,8 @@ import org.apache.flink.runtime.io.network.partition.ResultPartitionBuilder;
 import org.apache.flink.runtime.io.network.partition.ResultPartitionID;
 import org.apache.flink.runtime.io.network.partition.ResultPartitionManager;
 import org.apache.flink.runtime.io.network.partition.ResultPartitionType;
+import org.apache.flink.runtime.io.network.partition.ResultSubpartitionIndexSet;
 import org.apache.flink.runtime.io.network.partition.ResultSubpartitionView;
-import org.apache.flink.runtime.io.network.partition.consumer.SingleInputGate.SubpartitionInfo;
 import org.apache.flink.runtime.io.network.util.TestTaskEvent;
 import org.apache.flink.runtime.jobgraph.IntermediateDataSetID;
 import org.apache.flink.runtime.jobgraph.IntermediateResultPartitionID;
@@ -88,6 +89,7 @@ import java.util.List;
 import java.util.Map;
 import java.util.Optional;
 import java.util.concurrent.atomic.AtomicReference;
+import java.util.stream.Collectors;
 
 import static java.util.Arrays.asList;
 import static org.apache.flink.runtime.checkpoint.CheckpointOptions.alignedNoTimeout;
@@ -106,10 +108,10 @@ import static org.assertj.core.api.Assertions.assertThat;
 import static org.assertj.core.api.Assertions.assertThatThrownBy;
 
 /** Tests for {@link SingleInputGate}. */
-public class SingleInputGateTest extends InputGateTestBase {
+class SingleInputGateTest extends InputGateTestBase {
 
     @Test
-    void testCheckpointsDeclinedUnlessAllChannelsAreKnown() throws CheckpointException {
+    void testCheckpointsDeclinedUnlessAllChannelsAreKnown() {
         SingleInputGate gate =
                 createInputGate(createNettyShuffleEnvironment(), 1, ResultPartitionType.PIPELINED);
         gate.setInputChannels(
@@ -125,7 +127,7 @@ public class SingleInputGateTest extends InputGateTestBase {
     }
 
     @Test
-    void testCheckpointsDeclinedUnlessStateConsumed() throws CheckpointException {
+    void testCheckpointsDeclinedUnlessStateConsumed() {
         SingleInputGate gate = createInputGate(createNettyShuffleEnvironment());
         checkState(!gate.getStateConsumedFuture().isDone());
         assertThatThrownBy(
@@ -152,7 +154,7 @@ public class SingleInputGateTest extends InputGateTestBase {
 
             // before setup
             assertThat(inputGate.getBufferPool()).isNull();
-            for (InputChannel inputChannel : inputGate.getInputChannels().values()) {
+            for (InputChannel inputChannel : inputGate.inputChannels()) {
                 assertThat(
                                 inputChannel instanceof RecoveredInputChannel
                                         || inputChannel instanceof UnknownInputChannel)
@@ -170,7 +172,7 @@ public class SingleInputGateTest extends InputGateTestBase {
             // after setup
             assertThat(inputGate.getBufferPool()).isNotNull();
             assertThat(inputGate.getBufferPool().getNumberOfRequiredMemorySegments()).isEqualTo(1);
-            for (InputChannel inputChannel : inputGate.getInputChannels().values()) {
+            for (InputChannel inputChannel : inputGate.inputChannels()) {
                 if (inputChannel instanceof RemoteRecoveredInputChannel) {
                     assertThat(
                                     ((RemoteRecoveredInputChannel) inputChannel)
@@ -187,7 +189,7 @@ public class SingleInputGateTest extends InputGateTestBase {
             inputGate.convertRecoveredInputChannels();
             assertThat(inputGate.getBufferPool()).isNotNull();
             assertThat(inputGate.getBufferPool().getNumberOfRequiredMemorySegments()).isEqualTo(1);
-            for (InputChannel inputChannel : inputGate.getInputChannels().values()) {
+            for (InputChannel inputChannel : inputGate.inputChannels()) {
                 if (inputChannel instanceof RemoteInputChannel) {
                     assertThat(((RemoteInputChannel) inputChannel).getNumberOfAvailableBuffers())
                             .isEqualTo(2);
@@ -635,11 +637,13 @@ public class SingleInputGateTest extends InputGateTestBase {
                 };
 
         int initialBackoff = 137;
+        int partitionRequestTimeout = 600;
         int maxBackoff = 1001;
 
         final NettyShuffleEnvironment netEnv =
                 new NettyShuffleEnvironmentBuilder()
                         .setPartitionRequestInitialBackoff(initialBackoff)
+                        .setPartitionRequestTimeout(partitionRequestTimeout)
                         .setPartitionRequestMaxBackoff(maxBackoff)
                         .build();
 
@@ -659,7 +663,8 @@ public class SingleInputGateTest extends InputGateTestBase {
 
             assertThat(gate.getConsumedPartitionType()).isEqualTo(ResultPartitionType.PIPELINED);
 
-            Map<SubpartitionInfo, InputChannel> channelMap = gate.getInputChannels();
+            Map<Tuple2<IntermediateResultPartitionID, InputChannelInfo>, InputChannel> channelMap =
+                    gate.getInputChannels();
 
             assertThat(channelMap.size()).isEqualTo(3);
             channelMap
@@ -672,17 +677,13 @@ public class SingleInputGateTest extends InputGateTestBase {
                                     throw new RuntimeException(e);
                                 }
                             });
-            InputChannel localChannel = channelMap.get(createSubpartitionInfo(partitionIds[0]));
+            InputChannel localChannel = getTheOnlyInputChannelInPartition(gate, partitionIds[0]);
             assertThat(localChannel.getClass()).isEqualTo(LocalInputChannel.class);
 
-            InputChannel remoteChannel = channelMap.get(createSubpartitionInfo(partitionIds[1]));
-            assertThat(remoteChannel.getClass()).isEqualTo(RemoteInputChannel.class);
-
-            InputChannel unknownChannel = channelMap.get(createSubpartitionInfo(partitionIds[2]));
+            InputChannel unknownChannel = getTheOnlyInputChannelInPartition(gate, partitionIds[2]);
             assertThat(unknownChannel.getClass()).isEqualTo(UnknownInputChannel.class);
 
-            InputChannel[] channels =
-                    new InputChannel[] {localChannel, remoteChannel, unknownChannel};
+            InputChannel[] channels = new InputChannel[] {localChannel, unknownChannel};
             for (InputChannel ch : channels) {
                 assertThat(ch.getCurrentBackoff()).isEqualTo(0);
 
@@ -700,6 +701,22 @@ public class SingleInputGateTest extends InputGateTestBase {
 
                 assertThat(ch.increaseBackoff()).isFalse();
             }
+
+            InputChannel remoteChannel = getTheOnlyInputChannelInPartition(gate, partitionIds[1]);
+            assertThat(remoteChannel.getClass()).isEqualTo(RemoteInputChannel.class);
+
+            assertThat(remoteChannel.getCurrentBackoff()).isEqualTo(0);
+
+            assertThat(remoteChannel.increaseBackoff()).isTrue();
+            assertThat(remoteChannel.getCurrentBackoff()).isEqualTo(partitionRequestTimeout);
+
+            assertThat(remoteChannel.increaseBackoff()).isTrue();
+            assertThat(remoteChannel.getCurrentBackoff()).isEqualTo(partitionRequestTimeout * 2);
+
+            assertThat(remoteChannel.increaseBackoff()).isTrue();
+            assertThat(remoteChannel.getCurrentBackoff()).isEqualTo(partitionRequestTimeout * 3);
+
+            assertThat(remoteChannel.increaseBackoff()).isFalse();
         }
     }
 
@@ -774,11 +791,7 @@ public class SingleInputGateTest extends InputGateTestBase {
 
             RemoteInputChannel remote =
                     (RemoteInputChannel)
-                            inputGate
-                                    .getInputChannels()
-                                    .get(
-                                            createSubpartitionInfo(
-                                                    resultPartitionId.getPartitionId()));
+                            getTheOnlyInputChannelInPartition(inputGate, resultPartitionId);
             // only the exclusive buffers should be assigned/available now
             assertThat(remote.getNumberOfAvailableBuffers()).isEqualTo(buffersPerChannel);
 
@@ -833,19 +846,9 @@ public class SingleInputGateTest extends InputGateTestBase {
             inputGate.setInputChannels(inputChannels);
             inputGate.setup();
 
-            assertThat(
-                            inputGate
-                                    .getInputChannels()
-                                    .get(
-                                            createSubpartitionInfo(
-                                                    remoteResultPartitionId.getPartitionId())))
+            assertThat(getTheOnlyInputChannelInPartition(inputGate, remoteResultPartitionId))
                     .isInstanceOf(UnknownInputChannel.class);
-            assertThat(
-                            inputGate
-                                    .getInputChannels()
-                                    .get(
-                                            createSubpartitionInfo(
-                                                    localResultPartitionId.getPartitionId())))
+            assertThat(getTheOnlyInputChannelInPartition(inputGate, localResultPartitionId))
                     .isInstanceOf(UnknownInputChannel.class);
 
             ResourceID localLocation = ResourceID.generate();
@@ -856,19 +859,9 @@ public class SingleInputGateTest extends InputGateTestBase {
                     createRemoteWithIdAndLocation(
                             remoteResultPartitionId.getPartitionId(), ResourceID.generate()));
 
-            assertThat(
-                            inputGate
-                                    .getInputChannels()
-                                    .get(
-                                            createSubpartitionInfo(
-                                                    remoteResultPartitionId.getPartitionId())))
+            assertThat(getTheOnlyInputChannelInPartition(inputGate, remoteResultPartitionId))
                     .isInstanceOf(RemoteInputChannel.class);
-            assertThat(
-                            inputGate
-                                    .getInputChannels()
-                                    .get(
-                                            createSubpartitionInfo(
-                                                    localResultPartitionId.getPartitionId())))
+            assertThat(getTheOnlyInputChannelInPartition(inputGate, localResultPartitionId))
                     .isInstanceOf(UnknownInputChannel.class);
 
             // Trigger updates to local input channel from unknown input channel
@@ -877,19 +870,9 @@ public class SingleInputGateTest extends InputGateTestBase {
                     createRemoteWithIdAndLocation(
                             localResultPartitionId.getPartitionId(), localLocation));
 
-            assertThat(
-                            inputGate
-                                    .getInputChannels()
-                                    .get(
-                                            createSubpartitionInfo(
-                                                    remoteResultPartitionId.getPartitionId())))
+            assertThat(getTheOnlyInputChannelInPartition(inputGate, remoteResultPartitionId))
                     .isInstanceOf(RemoteInputChannel.class);
-            assertThat(
-                            inputGate
-                                    .getInputChannels()
-                                    .get(
-                                            createSubpartitionInfo(
-                                                    localResultPartitionId.getPartitionId())))
+            assertThat(getTheOnlyInputChannelInPartition(inputGate, localResultPartitionId))
                     .isInstanceOf(LocalInputChannel.class);
         }
     }
@@ -919,30 +902,24 @@ public class SingleInputGateTest extends InputGateTestBase {
                         new TestingConnectionManager(),
                         new TestingResultPartitionManager(new NoOpResultSubpartitionView()));
 
-        for (InputChannel channel : gate.getInputChannels().values()) {
+        for (InputChannel channel : gate.inputChannels()) {
             if (channel instanceof ChannelStateHolder) {
                 ((ChannelStateHolder) channel).setChannelStateWriter(ChannelStateWriter.NO_OP);
             }
         }
 
-        SubpartitionInfo info1 = createSubpartitionInfo(partitionIds[0], 0);
-        SubpartitionInfo info2 = createSubpartitionInfo(partitionIds[0], 1);
-        SubpartitionInfo info3 = createSubpartitionInfo(partitionIds[1], 0);
-        SubpartitionInfo info4 = createSubpartitionInfo(partitionIds[1], 1);
-        SubpartitionInfo info5 = createSubpartitionInfo(partitionIds[2], 0);
-        SubpartitionInfo info6 = createSubpartitionInfo(partitionIds[2], 1);
+        for (int i = 0; i < 3; i++) {
+            assertThat(
+                            getInputChannelsInPartition(gate, partitionIds[i]).stream()
+                                    .map(InputChannel::getConsumedSubpartitionIndexSet)
+                                    .collect(Collectors.toList()))
+                    .containsExactlyInAnyOrder(
+                            new ResultSubpartitionIndexSet(0), new ResultSubpartitionIndexSet(1));
+        }
 
-        assertThat(gate.getInputChannels().size()).isEqualTo(6);
-        assertThat(gate.getInputChannels().get(info1).getConsumedSubpartitionIndex()).isEqualTo(0);
-        assertThat(gate.getInputChannels().get(info2).getConsumedSubpartitionIndex()).isEqualTo(1);
-        assertThat(gate.getInputChannels().get(info3).getConsumedSubpartitionIndex()).isEqualTo(0);
-        assertThat(gate.getInputChannels().get(info4).getConsumedSubpartitionIndex()).isEqualTo(1);
-        assertThat(gate.getInputChannels().get(info5).getConsumedSubpartitionIndex()).isEqualTo(0);
-        assertThat(gate.getInputChannels().get(info6).getConsumedSubpartitionIndex()).isEqualTo(1);
-
-        assertChannelsType(gate, LocalRecoveredInputChannel.class, Arrays.asList(info1, info2));
-        assertChannelsType(gate, RemoteRecoveredInputChannel.class, Arrays.asList(info3, info4));
-        assertChannelsType(gate, UnknownInputChannel.class, Arrays.asList(info5, info6));
+        assertChannelsType(gate, LocalRecoveredInputChannel.class, partitionIds[0]);
+        assertChannelsType(gate, RemoteRecoveredInputChannel.class, partitionIds[1]);
+        assertChannelsType(gate, UnknownInputChannel.class, partitionIds[2]);
 
         // test setup
         gate.setup();
@@ -957,10 +934,10 @@ public class SingleInputGateTest extends InputGateTestBase {
         // test request partitions
         gate.requestPartitions();
         gate.pollNext();
-        assertChannelsType(gate, LocalInputChannel.class, Arrays.asList(info1, info2));
-        assertChannelsType(gate, RemoteInputChannel.class, Arrays.asList(info3, info4));
-        assertChannelsType(gate, UnknownInputChannel.class, Arrays.asList(info5, info6));
-        for (InputChannel inputChannel : gate.getInputChannels().values()) {
+        assertChannelsType(gate, LocalInputChannel.class, partitionIds[0]);
+        assertChannelsType(gate, RemoteInputChannel.class, partitionIds[1]);
+        assertChannelsType(gate, UnknownInputChannel.class, partitionIds[2]);
+        for (InputChannel inputChannel : gate.inputChannels()) {
             if (inputChannel instanceof RemoteInputChannel) {
                 assertThat(((RemoteInputChannel) inputChannel).getPartitionRequestClient())
                         .isNotNull();
@@ -973,15 +950,15 @@ public class SingleInputGateTest extends InputGateTestBase {
         // test update channels
         gate.updateInputChannel(
                 localLocation, createRemoteWithIdAndLocation(partitionIds[2], localLocation));
-        assertChannelsType(gate, LocalInputChannel.class, Arrays.asList(info1, info2));
-        assertChannelsType(gate, RemoteInputChannel.class, Arrays.asList(info3, info4));
-        assertChannelsType(gate, LocalInputChannel.class, Arrays.asList(info5, info6));
+        assertChannelsType(gate, LocalInputChannel.class, partitionIds[0]);
+        assertChannelsType(gate, RemoteInputChannel.class, partitionIds[1]);
+        assertChannelsType(gate, LocalInputChannel.class, partitionIds[2]);
     }
 
     private void assertChannelsType(
-            SingleInputGate gate, Class<?> clazz, List<SubpartitionInfo> infos) {
-        for (SubpartitionInfo subpartitionInfo : infos) {
-            assertThat(gate.getInputChannels().get(subpartitionInfo)).isInstanceOf(clazz);
+            SingleInputGate gate, Class<?> clazz, IntermediateResultPartitionID partitionID) {
+        for (InputChannel inputChannel : getInputChannelsInPartition(gate, partitionID)) {
+            assertThat(inputChannel).isInstanceOf(clazz);
         }
     }
 
@@ -1026,7 +1003,7 @@ public class SingleInputGateTest extends InputGateTestBase {
             resultPartition.setup();
             setupInputGate(inputGate, inputChannels);
 
-            remoteInputChannel.onBuffer(createBuffer(1), 0, 0);
+            remoteInputChannel.onBuffer(createBuffer(1), 0, 0, 0);
             assertThat(inputGate.getNumberOfQueuedBuffers()).isEqualTo(1);
 
             resultPartition.emitRecord(ByteBuffer.allocate(1), 0);
@@ -1121,7 +1098,7 @@ public class SingleInputGateTest extends InputGateTestBase {
                             .build();
 
             int channelCounter = 0;
-            for (InputChannel inputChannel : gate.getInputChannels().values()) {
+            for (InputChannel inputChannel : gate.inputChannels()) {
                 InputChannelInfo channelInfo = inputChannel.getChannelInfo();
 
                 assertThat(channelInfo.getGateIdx()).isEqualTo(i);
@@ -1242,7 +1219,7 @@ public class SingleInputGateTest extends InputGateTestBase {
                         new TestingResultPartitionManager(new NoOpResultSubpartitionView()));
         gate.setup();
 
-        for (InputChannel inputChannel : gate.getInputChannels().values()) {
+        for (InputChannel inputChannel : gate.inputChannels()) {
             if (inputChannel instanceof RemoteInputChannel) {
                 assertThat(((RemoteInputChannel) inputChannel).getInitialCredit()).isEqualTo(0);
             }
@@ -1264,14 +1241,27 @@ public class SingleInputGateTest extends InputGateTestBase {
                 .isEqualTo(totalFloatingBuffersPerGate);
     }
 
-    private static SubpartitionInfo createSubpartitionInfo(
-            IntermediateResultPartitionID partitionId) {
-        return createSubpartitionInfo(partitionId, 0);
+    private static List<InputChannel> getInputChannelsInPartition(
+            SingleInputGate inputGate, IntermediateResultPartitionID resultPartitionId) {
+        return inputGate.getInputChannels().entrySet().stream()
+                .filter(x -> x.getKey().f0.equals(resultPartitionId))
+                .map(Map.Entry::getValue)
+                .collect(Collectors.toList());
     }
 
-    private static SubpartitionInfo createSubpartitionInfo(
-            IntermediateResultPartitionID partitionId, int subpartitionIndex) {
-        return new SubpartitionInfo(partitionId, subpartitionIndex);
+    private static InputChannel getTheOnlyInputChannelInPartition(
+            SingleInputGate inputGate, ResultPartitionID resultPartitionId) {
+        return getTheOnlyInputChannelInPartition(inputGate, resultPartitionId.getPartitionId());
+    }
+
+    private static InputChannel getTheOnlyInputChannelInPartition(
+            SingleInputGate inputGate, IntermediateResultPartitionID resultPartitionId) {
+        List<InputChannel> inputChannels =
+                getInputChannelsInPartition(inputGate, resultPartitionId);
+
+        assertThat(inputChannels).hasSize(1);
+
+        return inputChannels.get(0);
     }
 
     static SingleInputGate createSingleInputGate(
@@ -1454,7 +1444,7 @@ public class SingleInputGateTest extends InputGateTestBase {
         @Override
         public ResultSubpartitionView createSubpartitionView(
                 ResultPartitionID partitionId,
-                int subpartitionIndex,
+                ResultSubpartitionIndexSet subpartitionIndexSet,
                 BufferAvailabilityListener availabilityListener)
                 throws IOException {
             ++counter;
