@@ -26,6 +26,7 @@ import org.apache.flink.runtime.io.network.api.StopMode;
 import org.apache.flink.runtime.io.network.api.serialization.EventSerializer;
 import org.apache.flink.runtime.io.network.buffer.Buffer;
 import org.apache.flink.runtime.io.network.partition.ResultPartitionID;
+import org.apache.flink.runtime.io.network.partition.ResultSubpartitionIndexSet;
 
 import javax.annotation.Nullable;
 
@@ -41,7 +42,7 @@ import static org.apache.flink.runtime.io.network.util.TestBufferFactory.createB
 import static org.apache.flink.util.Preconditions.checkArgument;
 import static org.apache.flink.util.Preconditions.checkNotNull;
 import static org.apache.flink.util.Preconditions.checkState;
-import static org.junit.Assert.fail;
+import static org.assertj.core.api.Assertions.assertThat;
 
 /** A mocked input channel. */
 public class TestInputChannel extends InputChannel {
@@ -89,7 +90,7 @@ public class TestInputChannel extends InputChannel {
                 inputGate,
                 channelIndex,
                 new ResultPartitionID(),
-                0,
+                new ResultSubpartitionIndexSet(0),
                 0,
                 0,
                 new SimpleCounter(),
@@ -178,7 +179,12 @@ public class TestInputChannel extends InputChannel {
     }
 
     @Override
-    void requestSubpartition() throws IOException, InterruptedException {}
+    void requestSubpartitions() throws IOException, InterruptedException {}
+
+    @Override
+    protected int peekNextBufferSubpartitionIdInternal() {
+        throw new UnsupportedOperationException();
+    }
 
     @Override
     public Optional<BufferAndAvailability> getNextBuffer()
@@ -249,7 +255,7 @@ public class TestInputChannel extends InputChannel {
     }
 
     @Override
-    public void notifyRequiredSegmentId(int segmentId) {
+    public void notifyRequiredSegmentId(int subpartitionId, int segmentId) {
         requiredSegmentIdFuture.complete(segmentId);
     }
 
@@ -259,12 +265,12 @@ public class TestInputChannel extends InputChannel {
 
     private void assertReturnedBuffersAreRecycled(boolean assertBuffers, boolean assertEvents) {
         for (Buffer b : allReturnedBuffers) {
-            if (b.isBuffer() && assertBuffers && !b.isRecycled()) {
-                fail("Data Buffer " + b + " not recycled");
-            }
-            if (!b.isBuffer() && assertEvents && !b.isRecycled()) {
-                fail("Event Buffer " + b + " not recycled");
-            }
+            assertThat(b.isBuffer() && assertBuffers && !b.isRecycled())
+                    .as("Data Buffer not recycled")
+                    .isFalse();
+            assertThat(!b.isBuffer() && assertEvents && !b.isRecycled())
+                    .as("Event Buffer not recycled")
+                    .isFalse();
         }
     }
 
