@@ -32,10 +32,9 @@ import org.apache.flink.runtime.operators.coordination.EventReceivingTasks.Event
 import org.apache.flink.runtime.scheduler.GlobalFailureHandler;
 import org.apache.flink.runtime.testtasks.NoOpInvokable;
 import org.apache.flink.util.ExceptionUtils;
-import org.apache.flink.util.TestLogger;
 
-import org.junit.After;
-import org.junit.Test;
+import org.junit.jupiter.api.AfterEach;
+import org.junit.jupiter.api.Test;
 
 import javax.annotation.Nonnull;
 import javax.annotation.Nullable;
@@ -51,19 +50,20 @@ import java.util.concurrent.locks.Condition;
 import java.util.concurrent.locks.ReentrantLock;
 import java.util.function.Function;
 
+import static org.apache.flink.core.testutils.FlinkAssertions.assertThatFuture;
 import static org.assertj.core.api.Assertions.assertThat;
 
 /**
  * A test that ensures the before/after conditions around event sending and checkpoint are met.
  * concurrency
  */
-public class OperatorCoordinatorHolderTest extends TestLogger {
+class OperatorCoordinatorHolderTest {
 
     private final GlobalFailureHandler globalFailureHandler = (t) -> globalFailure = t;
     private Throwable globalFailure;
 
-    @After
-    public void checkNoGlobalFailure() throws Exception {
+    @AfterEach
+    void checkNoGlobalFailure() throws Exception {
         if (globalFailure != null) {
             ExceptionUtils.rethrowException(globalFailure);
         }
@@ -72,7 +72,7 @@ public class OperatorCoordinatorHolderTest extends TestLogger {
     // ------------------------------------------------------------------------
 
     @Test
-    public void checkpointFutureInitiallyNotDone() throws Exception {
+    void checkpointFutureInitiallyNotDone() throws Exception {
         final EventReceivingTasks tasks = EventReceivingTasks.createForRunningTasks();
         final OperatorCoordinatorHolder holder =
                 createCoordinatorHolder(tasks, TestingOperatorCoordinator::new);
@@ -84,7 +84,7 @@ public class OperatorCoordinatorHolderTest extends TestLogger {
     }
 
     @Test
-    public void completedCheckpointFuture() throws Exception {
+    void completedCheckpointFuture() throws Exception {
         final EventReceivingTasks tasks = EventReceivingTasks.createForRunningTasks();
         final OperatorCoordinatorHolder holder =
                 createCoordinatorHolder(tasks, TestingOperatorCoordinator::new);
@@ -96,11 +96,11 @@ public class OperatorCoordinatorHolderTest extends TestLogger {
         getCoordinator(holder).getLastTriggeredCheckpoint().complete(testData);
 
         assertThat(checkpointFuture).isDone();
-        assertThat(checkpointFuture.get()).containsExactly(testData);
+        assertThatFuture(checkpointFuture).eventuallySucceeds().isEqualTo(testData);
     }
 
     @Test
-    public void eventsBeforeCheckpointFutureCompletionPassThrough() throws Exception {
+    void eventsBeforeCheckpointFutureCompletionPassThrough() throws Exception {
         final EventReceivingTasks tasks = EventReceivingTasks.createForRunningTasks();
         final OperatorCoordinatorHolder holder =
                 createCoordinatorHolder(tasks, TestingOperatorCoordinator::new);
@@ -113,7 +113,7 @@ public class OperatorCoordinatorHolderTest extends TestLogger {
     }
 
     @Test
-    public void eventsAreBlockedAfterCheckpointFutureCompletes() throws Exception {
+    void eventsAreBlockedAfterCheckpointFutureCompletes() throws Exception {
         final EventReceivingTasks tasks = EventReceivingTasks.createForRunningTasks();
         final OperatorCoordinatorHolder holder =
                 createCoordinatorHolder(tasks, TestingOperatorCoordinator::new);
@@ -121,11 +121,11 @@ public class OperatorCoordinatorHolderTest extends TestLogger {
         triggerAndCompleteCheckpoint(holder, 10L);
         getCoordinator(holder).getSubtaskGateway(0).sendEvent(new TestOperatorEvent(1337));
 
-        assertThat(tasks.getNumberOfSentEvents()).isEqualTo(0);
+        assertThat(tasks.getNumberOfSentEvents()).isZero();
     }
 
     @Test
-    public void abortedCheckpointReleasesBlockedEvents() throws Exception {
+    void abortedCheckpointReleasesBlockedEvents() throws Exception {
         final EventReceivingTasks tasks = EventReceivingTasks.createForRunningTasks();
         final OperatorCoordinatorHolder holder =
                 createCoordinatorHolder(tasks, TestingOperatorCoordinator::new);
@@ -138,7 +138,7 @@ public class OperatorCoordinatorHolderTest extends TestLogger {
     }
 
     @Test
-    public void acknowledgeCheckpointEventReleasesBlockedEvents() throws Exception {
+    void acknowledgeCheckpointEventReleasesBlockedEvents() throws Exception {
         final EventReceivingTasks tasks = EventReceivingTasks.createForRunningTasks();
         final OperatorCoordinatorHolder holder =
                 createCoordinatorHolder(tasks, TestingOperatorCoordinator::new);
@@ -151,7 +151,7 @@ public class OperatorCoordinatorHolderTest extends TestLogger {
     }
 
     @Test
-    public void restoreOpensGatewayEvents() throws Exception {
+    void restoreOpensGatewayEvents() throws Exception {
         final EventReceivingTasks tasks = EventReceivingTasks.createForRunningTasks();
         final OperatorCoordinatorHolder holder =
                 createCoordinatorHolder(tasks, TestingOperatorCoordinator::new);
@@ -164,7 +164,7 @@ public class OperatorCoordinatorHolderTest extends TestLogger {
     }
 
     @Test
-    public void lateCompleteCheckpointFutureDoesNotBlockEvents() throws Exception {
+    void lateCompleteCheckpointFutureDoesNotBlockEvents() throws Exception {
         final EventReceivingTasks tasks = EventReceivingTasks.createForRunningTasks();
         final OperatorCoordinatorHolder holder =
                 createCoordinatorHolder(tasks, TestingOperatorCoordinator::new);
@@ -188,7 +188,7 @@ public class OperatorCoordinatorHolderTest extends TestLogger {
     }
 
     @Test
-    public void takeCheckpointAfterSuccessfulCheckpoint() throws Exception {
+    void takeCheckpointAfterSuccessfulCheckpoint() throws Exception {
         final EventReceivingTasks tasks = EventReceivingTasks.createForRunningTasks();
         final OperatorCoordinatorHolder holder =
                 createCoordinatorHolder(tasks, TestingOperatorCoordinator::new);
@@ -218,7 +218,7 @@ public class OperatorCoordinatorHolderTest extends TestLogger {
     }
 
     @Test
-    public void takeCheckpointAfterAbortedCheckpoint() throws Exception {
+    void takeCheckpointAfterAbortedCheckpoint() throws Exception {
         final EventReceivingTasks tasks = EventReceivingTasks.createForRunningTasks();
         final OperatorCoordinatorHolder holder =
                 createCoordinatorHolder(tasks, TestingOperatorCoordinator::new);
@@ -244,7 +244,7 @@ public class OperatorCoordinatorHolderTest extends TestLogger {
     }
 
     @Test
-    public void testFailingJobMultipleTimesNotCauseCascadingJobFailure() throws Exception {
+    void testFailingJobMultipleTimesNotCauseCascadingJobFailure() throws Exception {
         Function<OperatorCoordinator.Context, OperatorCoordinator> coordinatorProvider =
                 context ->
                         new TestingOperatorCoordinator(context) {
@@ -279,7 +279,7 @@ public class OperatorCoordinatorHolderTest extends TestLogger {
     }
 
     @Test
-    public void checkpointCompletionWaitsForEventFutures() throws Exception {
+    void checkpointCompletionWaitsForEventFutures() throws Exception {
         final CompletableFuture<Acknowledge> ackFuture = new CompletableFuture<>();
         final EventReceivingTasks tasks =
                 EventReceivingTasks.createForRunningTasksWithRpcResult(ackFuture);
@@ -303,8 +303,7 @@ public class OperatorCoordinatorHolderTest extends TestLogger {
      * event directly after that.
      */
     @Test
-    public void verifyCheckpointEventOrderWhenCheckpointFutureCompletedImmediately()
-            throws Exception {
+    void verifyCheckpointEventOrderWhenCheckpointFutureCompletedImmediately() throws Exception {
         checkpointEventValueAtomicity(FutureCompletedInstantlyTestCoordinator::new);
     }
 
@@ -316,7 +315,7 @@ public class OperatorCoordinatorHolderTest extends TestLogger {
      * before completing the checkpoint future.
      */
     @Test
-    public void verifyCheckpointEventOrderWhenCheckpointFutureCompletesLate() throws Exception {
+    void verifyCheckpointEventOrderWhenCheckpointFutureCompletesLate() throws Exception {
         checkpointEventValueAtomicity(FutureCompletedAfterSendingEventsCoordinator::new);
     }
 
@@ -364,7 +363,7 @@ public class OperatorCoordinatorHolderTest extends TestLogger {
     }
 
     @Test
-    public void testCheckpointFailsIfSendingEventFailedAfterTrigger() throws Exception {
+    void testCheckpointFailsIfSendingEventFailedAfterTrigger() throws Exception {
         CompletableFuture<Acknowledge> eventSendingResult = new CompletableFuture<>();
         final EventReceivingTasks tasks =
                 EventReceivingTasks.createForRunningTasksWithRpcResult(eventSendingResult);
@@ -386,7 +385,7 @@ public class OperatorCoordinatorHolderTest extends TestLogger {
     }
 
     @Test
-    public void testCheckpointFailsIfSendingEventFailedBeforeTrigger() throws Exception {
+    void testCheckpointFailsIfSendingEventFailedBeforeTrigger() throws Exception {
         final ReorderableManualExecutorService executor = new ReorderableManualExecutorService();
         final ComponentMainThreadExecutor mainThreadExecutor =
                 new ComponentMainThreadExecutorServiceAdapter(
@@ -428,7 +427,7 @@ public class OperatorCoordinatorHolderTest extends TestLogger {
     }
 
     @Test
-    public void testControlGatewayAtSubtaskGranularity() throws Exception {
+    void testControlGatewayAtSubtaskGranularity() throws Exception {
         final EventReceivingTasks tasks = EventReceivingTasks.createForRunningTasks();
         final OperatorCoordinatorHolder holder =
                 createCoordinatorHolder(tasks, TestingOperatorCoordinator::new);
@@ -529,7 +528,7 @@ public class OperatorCoordinatorHolderTest extends TestLogger {
                                 new Configuration()),
                         UnregisteredMetricGroups.createUnregisteredJobManagerJobMetricGroup());
 
-        holder.lazyInitialize(globalFailureHandler, mainThreadExecutor);
+        holder.lazyInitialize(globalFailureHandler, mainThreadExecutor, null);
         holder.start();
 
         return holder;
