@@ -48,6 +48,7 @@ import static org.assertj.core.api.Assertions.assertThat;
 public abstract class ResourceManagerDriverTestBase<WorkerType extends ResourceIDRetrievable> {
 
     protected static final long TIMEOUT_SEC = 5L;
+    protected static final long TIMEOUT_SHOULD_NOT_HAPPEN_MS = 10;
 
     protected static final TaskExecutorProcessSpec TASK_EXECUTOR_PROCESS_SPEC =
             TaskExecutorProcessUtils.processSpecFromWorkerResourceSpec(
@@ -60,13 +61,13 @@ public abstract class ResourceManagerDriverTestBase<WorkerType extends ResourceI
                             runnable -> new Thread(runnable, MAIN_THREAD_NAME)));
 
     @Test
-    public void testInitialize() throws Exception {
+    void testInitialize() throws Exception {
         final Context context = createContext();
         context.runTest(context::validateInitialization);
     }
 
     @Test
-    public void testRecoverPreviousAttemptWorkers() throws Exception {
+    void testRecoverPreviousAttemptWorkers() throws Exception {
         final CompletableFuture<Collection<WorkerType>> recoveredWorkersFuture =
                 new CompletableFuture<>();
         final Context context = createContext();
@@ -80,7 +81,7 @@ public abstract class ResourceManagerDriverTestBase<WorkerType extends ResourceI
     }
 
     @Test
-    public void testTerminate() throws Exception {
+    void testTerminate() throws Exception {
         final Context context = createContext();
         context.runTest(
                 () -> {
@@ -90,22 +91,22 @@ public abstract class ResourceManagerDriverTestBase<WorkerType extends ResourceI
     }
 
     @Test
-    public void testDeregisterApplicationSucceeded() throws Exception {
+    void testDeregisterApplicationSucceeded() throws Exception {
         testDeregisterApplication(ApplicationStatus.SUCCEEDED);
     }
 
     @Test
-    public void testDeregisterApplicationFailed() throws Exception {
+    void testDeregisterApplicationFailed() throws Exception {
         testDeregisterApplication(ApplicationStatus.FAILED);
     }
 
     @Test
-    public void testDeregisterApplicationCanceled() throws Exception {
+    void testDeregisterApplicationCanceled() throws Exception {
         testDeregisterApplication(ApplicationStatus.CANCELED);
     }
 
     @Test
-    public void testDeregisterApplicationUnknown() throws Exception {
+    void testDeregisterApplicationUnknown() throws Exception {
         testDeregisterApplication(ApplicationStatus.UNKNOWN);
     }
 
@@ -119,7 +120,7 @@ public abstract class ResourceManagerDriverTestBase<WorkerType extends ResourceI
     }
 
     @Test
-    public void testRequestResource() throws Exception {
+    void testRequestResource() throws Exception {
         final Context context = createContext();
         context.runTest(
                 () -> {
@@ -131,7 +132,7 @@ public abstract class ResourceManagerDriverTestBase<WorkerType extends ResourceI
     }
 
     @Test
-    public void testReleaseResource() throws Exception {
+    void testReleaseResource() throws Exception {
         final CompletableFuture<WorkerType> requestResourceFuture = new CompletableFuture<>();
         final CompletableFuture<WorkerType> releaseResourceFuture = new CompletableFuture<>();
         final Context context = createContext();
