@@ -27,6 +27,8 @@ import org.apache.flink.testutils.TestingUtils;
 
 import java.time.Duration;
 
+import static org.apache.flink.configuration.TaskManagerOptions.TaskManagerLoadBalanceMode;
+
 /** Builder for {@link SlotManagerConfiguration}. */
 public class SlotManagerConfigurationBuilder {
     private Time taskManagerRequestTimeout;
@@ -36,11 +38,14 @@ public class SlotManagerConfigurationBuilder {
     private boolean waitResultConsumedBeforeRelease;
     private WorkerResourceSpec defaultWorkerResourceSpec;
     private int numSlotsPerWorker;
+    private int minSlotNum;
     private int maxSlotNum;
+    private CPUResource minTotalCpu;
     private CPUResource maxTotalCpu;
+    private MemorySize minTotalMem;
     private MemorySize maxTotalMem;
     private int redundantTaskManagerNum;
-    private boolean evenlySpreadOutSlots;
+    private TaskManagerLoadBalanceMode taskManagerLoadBalanceMode;
 
     private SlotManagerConfigurationBuilder() {
         this.taskManagerRequestTimeout = TestingUtils.infiniteTime();
@@ -51,12 +56,15 @@ public class SlotManagerConfigurationBuilder {
         this.waitResultConsumedBeforeRelease = true;
         this.defaultWorkerResourceSpec = WorkerResourceSpec.ZERO;
         this.numSlotsPerWorker = 1;
+        this.minSlotNum = ResourceManagerOptions.MIN_SLOT_NUM.defaultValue();
         this.maxSlotNum = ResourceManagerOptions.MAX_SLOT_NUM.defaultValue();
+        this.minTotalCpu = new CPUResource(Double.MIN_VALUE);
         this.maxTotalCpu = new CPUResource(Double.MAX_VALUE);
+        this.minTotalMem = MemorySize.ZERO;
         this.maxTotalMem = MemorySize.MAX_VALUE;
         this.redundantTaskManagerNum =
                 ResourceManagerOptions.REDUNDANT_TASK_MANAGER_NUM.defaultValue();
-        this.evenlySpreadOutSlots = false;
+        this.taskManagerLoadBalanceMode = TaskManagerLoadBalanceMode.NONE;
     }
 
     public static SlotManagerConfigurationBuilder newBuilder() {
@@ -103,16 +111,28 @@ public class SlotManagerConfigurationBuilder {
         return this;
     }
 
+    public void setMinSlotNum(int minSlotNum) {
+        this.minSlotNum = minSlotNum;
+    }
+
     public SlotManagerConfigurationBuilder setMaxSlotNum(int maxSlotNum) {
         this.maxSlotNum = maxSlotNum;
         return this;
     }
 
+    public void setMinTotalCpu(CPUResource minTotalCpu) {
+        this.minTotalCpu = minTotalCpu;
+    }
+
     public SlotManagerConfigurationBuilder setMaxTotalCpu(CPUResource maxTotalCpu) {
         this.maxTotalCpu = maxTotalCpu;
         return this;
     }
 
+    public void setMinTotalMem(MemorySize minTotalMem) {
+        this.minTotalMem = minTotalMem;
+    }
+
     public SlotManagerConfigurationBuilder setMaxTotalMem(MemorySize maxTotalMem) {
         this.maxTotalMem = maxTotalMem;
         return this;
@@ -123,8 +143,9 @@ public class SlotManagerConfigurationBuilder {
         return this;
     }
 
-    public SlotManagerConfigurationBuilder setEvenlySpreadOutSlots(boolean evenlySpreadOutSlots) {
-        this.evenlySpreadOutSlots = evenlySpreadOutSlots;
+    public SlotManagerConfigurationBuilder setTaskManagerLoadBalanceMode(
+            TaskManagerLoadBalanceMode taskManagerLoadBalanceMode) {
+        this.taskManagerLoadBalanceMode = taskManagerLoadBalanceMode;
         return this;
     }
 
@@ -135,14 +156,14 @@ public class SlotManagerConfigurationBuilder {
                 requirementCheckDelay,
                 declareNeededResourceDelay,
                 waitResultConsumedBeforeRelease,
-                evenlySpreadOutSlots
-                        ? LeastUtilizationSlotMatchingStrategy.INSTANCE
-                        : AnyMatchingSlotMatchingStrategy.INSTANCE,
-                evenlySpreadOutSlots,
+                taskManagerLoadBalanceMode,
                 defaultWorkerResourceSpec,
                 numSlotsPerWorker,
+                minSlotNum,
                 maxSlotNum,
+                minTotalCpu,
                 maxTotalCpu,
+                minTotalMem,
                 maxTotalMem,
                 redundantTaskManagerNum);
     }
