@@ -63,6 +63,7 @@ import org.junit.jupiter.api.Test;
 
 import java.util.ArrayList;
 import java.util.Arrays;
+import java.util.Collection;
 import java.util.Collections;
 import java.util.HashMap;
 import java.util.List;
@@ -215,6 +216,47 @@ class JobExceptionsHandlerTest {
         assertThat(response.getExceptionHistory().isTruncated()).isFalse();
     }
 
+    @Test
+    void testWithExceptionHistoryAndConcurrentGlobalFailure()
+            throws HandlerRequestException, ExecutionException, InterruptedException {
+        final ExceptionHistoryEntry otherFailure =
+                ExceptionHistoryEntry.createGlobal(
+                        new RuntimeException("exception #1"),
+                        CompletableFuture.completedFuture(Collections.emptyMap()));
+        final RootExceptionHistoryEntry rootCause =
+                fromGlobalFailure(
+                        new RuntimeException("exception #0"),
+                        System.currentTimeMillis(),
+                        Collections.singleton(otherFailure));
+
+        final ExecutionGraphInfo executionGraphInfo = createExecutionGraphInfo(rootCause);
+        final HandlerRequest<EmptyRequestBody> request =
+                createRequest(executionGraphInfo.getJobId(), 10);
+        final JobExceptionsInfoWithHistory response =
+                testInstance.handleRequest(request, executionGraphInfo);
+
+        assertThat(response.getExceptionHistory().getEntries())
+                .hasSize(1)
+                .satisfies(
+                        matching(
+                                contains(
+                                        historyContainsGlobalFailure(
+                                                rootCause.getException(),
+                                                rootCause.getTimestamp(),
+                                                matchesFailure(
+                                                        otherFailure.getException(),
+                                                        otherFailure.getTimestamp(),
+                                                        otherFailure.getFailureLabelsFuture(),
+                                                        otherFailure.getFailingTaskName(),
+                                                        JobExceptionsHandler.toString(
+                                                                otherFailure
+                                                                        .getTaskManagerLocation()),
+                                                        JobExceptionsHandler.toTaskManagerId(
+                                                                otherFailure
+                                                                        .getTaskManagerLocation()))))));
+        assertThat(response.getExceptionHistory().isTruncated()).isFalse();
+    }
+
     @Test
     void testWithExceptionHistoryWithMatchingFailureLabel()
             throws HandlerRequestException, ExecutionException, InterruptedException {
@@ -540,13 +582,20 @@ class JobExceptionsHandlerTest {
     }
 
     private static RootExceptionHistoryEntry fromGlobalFailure(Throwable cause, long timestamp) {
+        return fromGlobalFailure(cause, timestamp, Collections.emptySet());
+    }
+
+    private static RootExceptionHistoryEntry fromGlobalFailure(
+            Throwable cause,
+            long timestamp,
+            Collection<ExceptionHistoryEntry> concurrentExceptions) {
         return new RootExceptionHistoryEntry(
                 cause,
                 timestamp,
                 FailureEnricherUtils.EMPTY_FAILURE_LABELS,
                 null,
                 null,
-                Collections.emptySet());
+                concurrentExceptions);
     }
 
     // -------- factory methods for instantiating new Matchers --------
