@@ -25,6 +25,7 @@ import org.apache.flink.runtime.execution.ExecutionState;
 import org.apache.flink.runtime.executiongraph.ErrorInfo;
 import org.apache.flink.runtime.executiongraph.ExecutionGraph;
 import org.apache.flink.runtime.executiongraph.TaskExecutionStateTransition;
+import org.apache.flink.runtime.failure.FailureEnricherUtils;
 import org.apache.flink.runtime.scheduler.ExecutionGraphHandler;
 import org.apache.flink.runtime.scheduler.OperatorCoordinatorHandler;
 import org.apache.flink.runtime.scheduler.exceptionhistory.ExceptionHistoryEntry;
@@ -198,7 +199,8 @@ class StopWithSavepointTest {
 
             ctx.setExpectRestarting(assertNonNull());
 
-            sws.handleGlobalFailure(new RuntimeException());
+            sws.handleGlobalFailure(
+                    new RuntimeException(), FailureEnricherUtils.EMPTY_FAILURE_LABELS);
         }
     }
 
@@ -217,7 +219,8 @@ class StopWithSavepointTest {
                                 .satisfies(FlinkAssertions.anyCauseMatches(RuntimeException.class));
                     });
 
-            sws.handleGlobalFailure(new RuntimeException());
+            sws.handleGlobalFailure(
+                    new RuntimeException(), FailureEnricherUtils.EMPTY_FAILURE_LABELS);
         }
     }
 
@@ -245,7 +248,11 @@ class StopWithSavepointTest {
             executionGraph.registerExecution(execution);
             TaskExecutionStateTransition taskExecutionStateTransition =
                     ExecutingTest.createFailingStateTransition(execution.getAttemptId(), exception);
-            assertThat(sws.updateTaskExecutionState(taskExecutionStateTransition)).isTrue();
+            assertThat(
+                            sws.updateTaskExecutionState(
+                                    taskExecutionStateTransition,
+                                    FailureEnricherUtils.EMPTY_FAILURE_LABELS))
+                    .isTrue();
         }
     }
 
@@ -269,7 +276,11 @@ class StopWithSavepointTest {
             executionGraph.registerExecution(execution);
             TaskExecutionStateTransition taskExecutionStateTransition =
                     ExecutingTest.createFailingStateTransition(execution.getAttemptId(), exception);
-            assertThat(sws.updateTaskExecutionState(taskExecutionStateTransition)).isTrue();
+            assertThat(
+                            sws.updateTaskExecutionState(
+                                    taskExecutionStateTransition,
+                                    FailureEnricherUtils.EMPTY_FAILURE_LABELS))
+                    .isTrue();
         }
     }
 
@@ -349,7 +360,11 @@ class StopWithSavepointTest {
             executionGraph.registerExecution(execution);
             TaskExecutionStateTransition taskExecutionStateTransition =
                     ExecutingTest.createFailingStateTransition(execution.getAttemptId(), exception);
-            assertThat(sws.updateTaskExecutionState(taskExecutionStateTransition)).isTrue();
+            assertThat(
+                            sws.updateTaskExecutionState(
+                                    taskExecutionStateTransition,
+                                    FailureEnricherUtils.EMPTY_FAILURE_LABELS))
+                    .isTrue();
         }
     }
 
@@ -638,6 +653,11 @@ class StopWithSavepointTest {
             cancellingStateValidator.close();
             executingStateTransition.close();
         }
+
+        @Override
+        public void handleGlobalFailure(Throwable cause) {
+            state.handleGlobalFailure(cause, FailureEnricherUtils.EMPTY_FAILURE_LABELS);
+        }
     }
 
     private static class MockCheckpointScheduling implements CheckpointScheduling {
