@@ -32,10 +32,9 @@ import org.apache.flink.runtime.jobgraph.JobVertex;
 import org.apache.flink.runtime.minicluster.MiniCluster;
 import org.apache.flink.runtime.minicluster.MiniClusterConfiguration;
 import org.apache.flink.runtime.testtasks.NoOpInvokable;
-import org.apache.flink.util.TestLogger;
 
-import org.junit.Before;
-import org.junit.Test;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 
 import java.util.Collections;
 import java.util.concurrent.BlockingQueue;
@@ -45,13 +44,10 @@ import java.util.concurrent.atomic.AtomicBoolean;
 import java.util.concurrent.atomic.AtomicReference;
 
 import static org.apache.flink.api.common.restartstrategy.RestartStrategies.fixedDelayRestart;
-import static org.junit.Assert.assertArrayEquals;
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertNotNull;
-import static org.junit.Assert.assertTrue;
+import static org.assertj.core.api.Assertions.assertThat;
 
 /** Tests for {@link ShuffleMaster}. */
-public class ShuffleMasterTest extends TestLogger {
+class ShuffleMasterTest {
 
     private static final String STOP_TRACKING_PARTITION_KEY = "stop_tracking_partition_key";
 
@@ -59,52 +55,46 @@ public class ShuffleMasterTest extends TestLogger {
 
     private static final String EXTERNAL_PARTITION_RELEASE_EVENT = "releasePartitionExternally";
 
-    @Before
-    public void before() {
+    @BeforeEach
+    void before() {
         TestShuffleMaster.partitionEvents.clear();
     }
 
     @Test
-    public void testShuffleMasterLifeCycle() throws Exception {
+    void testShuffleMasterLifeCycle() throws Exception {
         try (MiniCluster cluster = new MiniCluster(createClusterConfiguration(false))) {
             cluster.start();
             cluster.executeJobBlocking(createJobGraph());
         }
-        assertTrue(TestShuffleMaster.currentInstance.get().closed.get());
-
-        String[] expectedPartitionEvents =
-                new String[] {
-                    PARTITION_REGISTRATION_EVENT,
-                    PARTITION_REGISTRATION_EVENT,
-                    EXTERNAL_PARTITION_RELEASE_EVENT,
-                    EXTERNAL_PARTITION_RELEASE_EVENT,
-                };
-        assertArrayEquals(expectedPartitionEvents, TestShuffleMaster.partitionEvents.toArray());
+        assertThat(TestShuffleMaster.currentInstance.get().closed).isTrue();
+        assertThat(TestShuffleMaster.partitionEvents)
+                .containsExactly(
+                        PARTITION_REGISTRATION_EVENT,
+                        PARTITION_REGISTRATION_EVENT,
+                        EXTERNAL_PARTITION_RELEASE_EVENT,
+                        EXTERNAL_PARTITION_RELEASE_EVENT);
     }
 
     @Test
-    public void testStopTrackingPartition() throws Exception {
+    void testStopTrackingPartition() throws Exception {
         try (MiniCluster cluster = new MiniCluster(createClusterConfiguration(true))) {
             cluster.start();
             cluster.executeJobBlocking(createJobGraph());
         }
-        assertTrue(TestShuffleMaster.currentInstance.get().closed.get());
-
-        String[] expectedPartitionEvents =
-                new String[] {
-                    PARTITION_REGISTRATION_EVENT,
-                    PARTITION_REGISTRATION_EVENT,
-                    PARTITION_REGISTRATION_EVENT,
-                    PARTITION_REGISTRATION_EVENT,
-                    EXTERNAL_PARTITION_RELEASE_EVENT,
-                    EXTERNAL_PARTITION_RELEASE_EVENT,
-                };
-        assertArrayEquals(expectedPartitionEvents, TestShuffleMaster.partitionEvents.toArray());
+        assertThat(TestShuffleMaster.currentInstance.get().closed).isTrue();
+        assertThat(TestShuffleMaster.partitionEvents)
+                .containsExactly(
+                        PARTITION_REGISTRATION_EVENT,
+                        PARTITION_REGISTRATION_EVENT,
+                        PARTITION_REGISTRATION_EVENT,
+                        PARTITION_REGISTRATION_EVENT,
+                        EXTERNAL_PARTITION_RELEASE_EVENT,
+                        EXTERNAL_PARTITION_RELEASE_EVENT);
     }
 
     private MiniClusterConfiguration createClusterConfiguration(boolean stopTrackingPartition) {
         Configuration configuration = new Configuration();
-        configuration.setString(
+        configuration.set(
                 ShuffleServiceOptions.SHUFFLE_SERVICE_FACTORY_CLASS,
                 TestShuffleServiceFactory.class.getName());
         configuration.setBoolean(STOP_TRACKING_PARTITION_KEY, stopTrackingPartition);
@@ -169,8 +159,8 @@ public class ShuffleMasterTest extends TestLogger {
 
         @Override
         public void start() throws Exception {
-            assertFalse(started.get());
-            assertFalse(closed.get());
+            assertThat(started).isFalse();
+            assertThat(closed).isFalse();
             started.set(true);
             super.start();
         }
@@ -185,7 +175,7 @@ public class ShuffleMasterTest extends TestLogger {
         @Override
         public void registerJob(JobShuffleContext context) {
             assertShuffleMasterAlive();
-            assertTrue(jobContext.compareAndSet(null, context));
+            assertThat(jobContext.compareAndSet(null, context)).isTrue();
             super.registerJob(context);
         }
 
@@ -238,13 +228,13 @@ public class ShuffleMasterTest extends TestLogger {
         }
 
         private void assertShuffleMasterAlive() {
-            assertFalse(closed.get());
-            assertTrue(started.get());
+            assertThat(closed).isFalse();
+            assertThat(started).isTrue();
         }
 
         private void assertJobRegistered() {
             assertShuffleMasterAlive();
-            assertNotNull(jobContext.get());
+            assertThat(jobContext).isNotNull();
         }
     }
 }
