@@ -40,6 +40,7 @@ import org.apache.flink.runtime.state.metainfo.StateMetaInfoSnapshotReadersWrite
 import org.apache.flink.state.changelog.ChangelogKeyedStateBackend;
 import org.apache.flink.state.changelog.ChangelogState;
 import org.apache.flink.state.changelog.StateChangeOperation;
+import org.apache.flink.util.Preconditions;
 
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
@@ -51,7 +52,6 @@ import java.io.IOException;
 import java.io.ObjectInputStream;
 import java.util.Map;
 
-import static org.apache.flink.runtime.state.metainfo.StateMetaInfoSnapshotReadersWriters.StateTypeHint.KEYED_STATE;
 import static org.apache.flink.state.changelog.StateChangeOperation.METADATA;
 import static org.apache.flink.state.changelog.restore.FunctionDelegationHelper.delegateAggregateFunction;
 import static org.apache.flink.state.changelog.restore.FunctionDelegationHelper.delegateReduceFunction;
@@ -64,7 +64,7 @@ class ChangelogBackendLogApplier {
 
     public static void apply(
             StateChange stateChange,
-            ChangelogKeyedStateBackend<?> changelogBackend,
+            ChangelogRestoreTarget<?> changelogRestoreTarget,
             ClassLoader classLoader,
             Map<Short, StateID> stateIds)
             throws Exception {
@@ -73,7 +73,7 @@ class ChangelogBackendLogApplier {
         applyOperation(
                 StateChangeOperation.byCode(in.readByte()),
                 stateChange.getKeyGroup(),
-                changelogBackend,
+                changelogRestoreTarget,
                 in,
                 classLoader,
                 ChangelogApplierFactoryImpl.INSTANCE,
@@ -83,7 +83,7 @@ class ChangelogBackendLogApplier {
     private static void applyOperation(
             StateChangeOperation operation,
             int keyGroup,
-            ChangelogKeyedStateBackend<?> backend,
+            ChangelogRestoreTarget<?> changelogRestoreTarget,
             DataInputView in,
             ClassLoader classLoader,
             ChangelogApplierFactory factory,
@@ -91,15 +91,15 @@ class ChangelogBackendLogApplier {
             throws Exception {
         LOG.debug("apply {} in key group {}", operation, keyGroup);
         if (operation == METADATA) {
-            applyMetaDataChange(in, backend, classLoader, stateIds);
-        } else if (backend.getKeyGroupRange().contains(keyGroup)) {
-            applyDataChange(in, factory, backend, operation, stateIds);
+            applyMetaDataChange(in, changelogRestoreTarget, classLoader, stateIds);
+        } else if (changelogRestoreTarget.getKeyGroupRange().contains(keyGroup)) {
+            applyDataChange(in, factory, changelogRestoreTarget, operation, stateIds);
         }
     }
 
     private static void applyMetaDataChange(
             DataInputView in,
-            ChangelogKeyedStateBackend<?> backend,
+            ChangelogRestoreTarget<?> changelogRestoreTarget,
             ClassLoader classLoader,
             Map<Short, StateID> stateIds)
             throws Exception {
@@ -108,10 +108,10 @@ class ChangelogBackendLogApplier {
         RegisteredStateMetaInfoBase meta;
         switch (snapshot.getBackendStateType()) {
             case KEY_VALUE:
-                meta = restoreKvMetaData(backend, snapshot, in);
+                meta = restoreKvMetaData(changelogRestoreTarget, snapshot, in);
                 break;
             case PRIORITY_QUEUE:
-                meta = restorePqMetaData(backend, snapshot);
+                meta = restorePqMetaData(changelogRestoreTarget, snapshot);
                 break;
             default:
                 throw new RuntimeException(
@@ -147,7 +147,9 @@ class ChangelogBackendLogApplier {
     }
 
     private static RegisteredKeyValueStateBackendMetaInfo restoreKvMetaData(
-            ChangelogKeyedStateBackend<?> backend, StateMetaInfoSnapshot snapshot, DataInputView in)
+            ChangelogRestoreTarget<?> changelogRestoreTarget,
+            StateMetaInfoSnapshot snapshot,
+            DataInputView in)
             throws Exception {
         RegisteredKeyValueStateBackendMetaInfo meta =
                 new RegisteredKeyValueStateBackendMetaInfo(snapshot);
@@ -158,11 +160,10 @@ class ChangelogBackendLogApplier {
         // An alternative solution to load metadata "natively" by the base backends would require
         // base state to be always present, i.e. the 1st checkpoint would have to be "full" always.
         StateDescriptor stateDescriptor = toStateDescriptor(meta, defaultValue);
-        // todo: support changing ttl (FLINK-23143)
         if (ttlConfig.isEnabled()) {
             stateDescriptor.enableTimeToLive(ttlConfig);
         }
-        backend.getOrCreateKeyedState(meta.getNamespaceSerializer(), stateDescriptor);
+        changelogRestoreTarget.createKeyedState(meta.getNamespaceSerializer(), stateDescriptor);
         return meta;
     }
 
@@ -194,30 +195,31 @@ class ChangelogBackendLogApplier {
     }
 
     private static RegisteredPriorityQueueStateBackendMetaInfo restorePqMetaData(
-            ChangelogKeyedStateBackend<?> backend, StateMetaInfoSnapshot snapshot) {
+            ChangelogRestoreTarget<?> changelogRestoreTarget, StateMetaInfoSnapshot snapshot) {
         RegisteredPriorityQueueStateBackendMetaInfo meta =
                 new RegisteredPriorityQueueStateBackendMetaInfo(snapshot);
-        backend.create(meta.getName(), meta.getElementSerializer());
+        changelogRestoreTarget.createPqState(meta.getName(), meta.getElementSerializer());
         return meta;
     }
 
     private static StateMetaInfoSnapshot readStateMetaInfoSnapshot(
             DataInputView in, ClassLoader classLoader) throws IOException {
         int version = in.readInt();
-        StateMetaInfoReader reader =
-                StateMetaInfoSnapshotReadersWriters.getReader(version, KEYED_STATE);
+        StateMetaInfoReader reader = StateMetaInfoSnapshotReadersWriters.getReader(version);
         return reader.readStateMetaInfoSnapshot(in, classLoader);
     }
 
     private static void applyDataChange(
             DataInputView in,
             ChangelogApplierFactory factory,
-            ChangelogKeyedStateBackend<?> backend,
+            ChangelogRestoreTarget<?> changelogRestoreTarget,
             StateChangeOperation operation,
             Map<Short, StateID> stateIds)
             throws Exception {
         StateID id = checkNotNull(stateIds.get(in.readShort()));
-        ChangelogState state = backend.getExistingStateForRecovery(id.stateName, id.stateType);
+        ChangelogState state = changelogRestoreTarget.getExistingState(id.stateName, id.stateType);
+        Preconditions.checkState(
+                state != null, String.format("%s state %s not found", id.stateType, id.stateName));
         StateChangeApplier changeApplier = state.getChangeApplier(factory);
         changeApplier.apply(operation, in);
     }
