@@ -21,33 +21,36 @@ package org.apache.flink.contrib.streaming.state;
 import org.apache.flink.configuration.Configuration;
 import org.apache.flink.runtime.state.StateBackendMigrationTestBase;
 import org.apache.flink.runtime.state.filesystem.FsStateBackend;
+import org.apache.flink.testutils.junit.extensions.parameterized.Parameter;
+import org.apache.flink.testutils.junit.extensions.parameterized.ParameterizedTestExtension;
+import org.apache.flink.testutils.junit.extensions.parameterized.Parameters;
+import org.apache.flink.testutils.junit.utils.TempDirUtils;
 
-import org.junit.runner.RunWith;
-import org.junit.runners.Parameterized;
+import org.junit.jupiter.api.extension.ExtendWith;
 
 import java.io.IOException;
 import java.util.Arrays;
 import java.util.Collection;
 
 /** Tests for the partitioned state part of {@link RocksDBStateBackend}. */
-@RunWith(Parameterized.class)
+@ExtendWith(ParameterizedTestExtension.class)
 public class RocksDBStateBackendMigrationTest
         extends StateBackendMigrationTestBase<RocksDBStateBackend> {
 
-    @Parameterized.Parameters(name = "Incremental checkpointing: {0}")
+    @Parameters(name = "Incremental checkpointing: {0}")
     public static Collection<Boolean> parameters() {
         return Arrays.asList(false, true);
     }
 
-    @Parameterized.Parameter public boolean enableIncrementalCheckpointing;
+    @Parameter public boolean enableIncrementalCheckpointing;
 
     // Store it because we need it for the cleanup test.
     private String dbPath;
 
     @Override
     protected RocksDBStateBackend getStateBackend() throws IOException {
-        dbPath = tempFolder.newFolder().getAbsolutePath();
-        String checkpointPath = tempFolder.newFolder().toURI().toString();
+        dbPath = TempDirUtils.newFolder(tempFolder).getAbsolutePath();
+        String checkpointPath = TempDirUtils.newFolder(tempFolder).toURI().toString();
         RocksDBStateBackend backend =
                 new RocksDBStateBackend(
                         new FsStateBackend(checkpointPath), enableIncrementalCheckpointing);
