@@ -20,6 +20,8 @@ package org.apache.flink.streaming.runtime.tasks.mailbox;
 import org.apache.flink.annotation.Internal;
 import org.apache.flink.annotation.VisibleForTesting;
 import org.apache.flink.api.common.operators.MailboxExecutor;
+import org.apache.flink.metrics.SimpleCounter;
+import org.apache.flink.runtime.metrics.DescriptiveStatisticsHistogram;
 import org.apache.flink.streaming.runtime.tasks.StreamTaskActionExecutor;
 import org.apache.flink.streaming.runtime.tasks.mailbox.TaskMailbox.MailboxClosedException;
 import org.apache.flink.util.ExceptionUtils;
@@ -58,7 +60,7 @@ import static org.apache.flink.util.Preconditions.checkState;
  * up. For control flag changes by all other threads, that must happen through mailbox actions, this
  * is automatically the case.
  *
- * <p>This class has a open-prepareClose-close lifecycle that is connected with and maps to the
+ * <p>This class has an open-prepareClose-close lifecycle that is connected with and maps to the
  * lifecycle of the encapsulated {@link TaskMailbox} (which is open-quiesce-close).
  */
 @Internal
@@ -99,6 +101,8 @@ public class MailboxProcessor implements Closeable {
 
     private final StreamTaskActionExecutor actionExecutor;
 
+    private final MailboxMetricsController mailboxMetricsControl;
+
     @VisibleForTesting
     public MailboxProcessor() {
         this(MailboxDefaultAction.Controller::suspendDefaultAction);
@@ -117,11 +121,25 @@ public class MailboxProcessor implements Closeable {
             MailboxDefaultAction mailboxDefaultAction,
             TaskMailbox mailbox,
             StreamTaskActionExecutor actionExecutor) {
+        this(
+                mailboxDefaultAction,
+                mailbox,
+                actionExecutor,
+                new MailboxMetricsController(
+                        new DescriptiveStatisticsHistogram(10), new SimpleCounter()));
+    }
+
+    public MailboxProcessor(
+            MailboxDefaultAction mailboxDefaultAction,
+            TaskMailbox mailbox,
+            StreamTaskActionExecutor actionExecutor,
+            MailboxMetricsController mailboxMetricsControl) {
         this.mailboxDefaultAction = Preconditions.checkNotNull(mailboxDefaultAction);
         this.actionExecutor = Preconditions.checkNotNull(actionExecutor);
         this.mailbox = Preconditions.checkNotNull(mailbox);
         this.mailboxLoopRunning = true;
         this.suspendedDefaultAction = null;
+        this.mailboxMetricsControl = mailboxMetricsControl;
     }
 
     public MailboxExecutor getMainMailboxExecutor() {
@@ -137,6 +155,16 @@ public class MailboxProcessor implements Closeable {
         return new MailboxExecutorImpl(mailbox, priority, actionExecutor, this);
     }
 
+    /**
+     * Gets {@link MailboxMetricsController} for control and access to mailbox metrics.
+     *
+     * @return {@link MailboxMetricsController}.
+     */
+    @VisibleForTesting
+    public MailboxMetricsController getMailboxMetricsControl() {
+        return this.mailboxMetricsControl;
+    }
+
     /** Lifecycle method to close the mailbox for action submission. */
     public void prepareClose() {
         mailbox.quiesce();
@@ -174,7 +202,7 @@ public class MailboxProcessor implements Closeable {
      */
     public void drain() throws Exception {
         for (final Mail mail : mailbox.drain()) {
-            mail.run();
+            runMail(mail);
         }
     }
 
@@ -194,14 +222,14 @@ public class MailboxProcessor implements Closeable {
 
         assert localMailbox.getState() == TaskMailbox.State.OPEN : "Mailbox must be opened!";
 
-        final MailboxController defaultActionContext = new MailboxController(this);
+        final MailboxController mailboxController = new MailboxController(this);
 
         while (isNextLoopPossible()) {
             // The blocking `processMail` call will not return until default action is available.
             processMail(localMailbox, false);
             if (isNextLoopPossible()) {
                 mailboxDefaultAction.runDefaultAction(
-                        defaultActionContext); // lock is acquired inside default action as needed
+                        mailboxController); // lock is acquired inside default action as needed
             }
         }
     }
@@ -335,7 +363,9 @@ public class MailboxProcessor implements Closeable {
                 maybeMail = Optional.of(mailbox.take(MIN_PRIORITY));
             }
             maybePauseIdleTimer();
-            maybeMail.get().run();
+
+            runMail(maybeMail.get());
+
             maybeRestartIdleTimer();
             processedSomething = true;
         }
@@ -350,7 +380,7 @@ public class MailboxProcessor implements Closeable {
             if (processedMails++ == 0) {
                 maybePauseIdleTimer();
             }
-            maybeMail.get().run();
+            runMail(maybeMail.get());
             if (singleStep) {
                 break;
             }
@@ -363,6 +393,20 @@ public class MailboxProcessor implements Closeable {
         }
     }
 
+    private void runMail(Mail mail) throws Exception {
+        mailboxMetricsControl.getMailCounter().inc();
+        mail.run();
+        if (!suspended) {
+            // start latency measurement on first mail that is not suspending mailbox execution,
+            // i.e., on first non-poison mail, otherwise latency measurement is not started to avoid
+            // overhead
+            if (!mailboxMetricsControl.isLatencyMeasurementStarted()
+                    && mailboxMetricsControl.isLatencyMeasurementSetup()) {
+                mailboxMetricsControl.startLatencyMeasurement();
+            }
+        }
+    }
+
     private void maybePauseIdleTimer() {
         if (suspendedDefaultAction != null && suspendedDefaultAction.suspensionTimer != null) {
             suspendedDefaultAction.suspensionTimer.markEnd();
@@ -391,7 +435,6 @@ public class MailboxProcessor implements Closeable {
             suspendedDefaultAction = new DefaultActionSuspension(suspensionTimer);
         }
 
-        maybeRestartIdleTimer();
         return suspendedDefaultAction;
     }
 
@@ -410,7 +453,6 @@ public class MailboxProcessor implements Closeable {
         return mailboxLoopRunning;
     }
 
-    @VisibleForTesting
     public boolean hasMail() {
         return mailbox.hasMail();
     }
@@ -469,7 +511,6 @@ public class MailboxProcessor implements Closeable {
         }
 
         private void resumeInternal() {
-            maybePauseIdleTimer();
             if (suspendedDefaultAction == this) {
                 suspendedDefaultAction = null;
             }
