@@ -24,19 +24,20 @@ import org.apache.flink.api.common.SupportsConcurrentExecutionAttempts;
 import org.apache.flink.api.common.operators.SlotSharingGroup;
 import org.apache.flink.api.common.typeinfo.TypeInformation;
 import org.apache.flink.api.connector.sink2.Sink;
-import org.apache.flink.api.connector.sink2.TwoPhaseCommittingSink;
+import org.apache.flink.api.connector.sink2.SupportsCommitter;
 import org.apache.flink.api.dag.Transformation;
 import org.apache.flink.configuration.CoreOptions;
 import org.apache.flink.streaming.api.connector.sink2.CommittableMessage;
 import org.apache.flink.streaming.api.connector.sink2.CommittableMessageTypeInfo;
 import org.apache.flink.streaming.api.connector.sink2.StandardSinkTopologies;
-import org.apache.flink.streaming.api.connector.sink2.WithPostCommitTopology;
-import org.apache.flink.streaming.api.connector.sink2.WithPreCommitTopology;
-import org.apache.flink.streaming.api.connector.sink2.WithPreWriteTopology;
+import org.apache.flink.streaming.api.connector.sink2.SupportsPostCommitTopology;
+import org.apache.flink.streaming.api.connector.sink2.SupportsPreCommitTopology;
+import org.apache.flink.streaming.api.connector.sink2.SupportsPreWriteTopology;
 import org.apache.flink.streaming.api.datastream.CustomSinkOperatorUidHashes;
 import org.apache.flink.streaming.api.datastream.DataStream;
 import org.apache.flink.streaming.api.environment.StreamExecutionEnvironment;
 import org.apache.flink.streaming.api.graph.TransformationTranslator;
+import org.apache.flink.streaming.api.transformations.OneInputTransformation;
 import org.apache.flink.streaming.api.transformations.PartitionTransformation;
 import org.apache.flink.streaming.api.transformations.PhysicalTransformation;
 import org.apache.flink.streaming.api.transformations.SinkTransformation;
@@ -44,21 +45,28 @@ import org.apache.flink.streaming.api.transformations.StreamExchangeMode;
 import org.apache.flink.streaming.runtime.operators.sink.CommitterOperatorFactory;
 import org.apache.flink.streaming.runtime.operators.sink.SinkWriterOperatorFactory;
 import org.apache.flink.streaming.runtime.partitioner.ForwardPartitioner;
+import org.apache.flink.util.Preconditions;
 
 import javax.annotation.Nullable;
 
+import java.util.ArrayDeque;
 import java.util.Collection;
 import java.util.Collections;
+import java.util.HashSet;
 import java.util.List;
 import java.util.Optional;
+import java.util.Queue;
+import java.util.Set;
 import java.util.function.BiConsumer;
 import java.util.function.Function;
+import java.util.function.Supplier;
+import java.util.stream.Collectors;
 
 import static org.apache.flink.util.Preconditions.checkState;
 
 /**
  * A {@link org.apache.flink.streaming.api.graph.TransformationTranslator} for the {@link
- * org.apache.flink.streaming.api.transformations.SinkTransformation}.
+ * SinkTransformation}.
  */
 @Internal
 public class SinkTransformationTranslator<Input, Output>
@@ -135,16 +143,27 @@ public class SinkTransformationTranslator<Input, Output>
 
             DataStream<T> prewritten = inputStream;
 
-            if (sink instanceof WithPreWriteTopology) {
+            if (sink instanceof SupportsPreWriteTopology) {
                 prewritten =
                         adjustTransformations(
                                 prewritten,
-                                ((WithPreWriteTopology<T>) sink)::addPreWriteTopology,
+                                ((SupportsPreWriteTopology<T>) sink)::addPreWriteTopology,
                                 true,
                                 sink instanceof SupportsConcurrentExecutionAttempts);
             }
 
-            if (sink instanceof TwoPhaseCommittingSink) {
+            if (sink instanceof SupportsPreCommitTopology) {
+                Preconditions.checkArgument(
+                        sink instanceof SupportsCommitter,
+                        "Sink with SupportsPreCommitTopology should implement SupportsCommitter");
+            }
+            if (sink instanceof SupportsPostCommitTopology) {
+                Preconditions.checkArgument(
+                        sink instanceof SupportsCommitter,
+                        "Sink with SupportsPostCommitTopology should implement SupportsCommitter");
+            }
+
+            if (sink instanceof SupportsCommitter) {
                 addCommittingTopology(sink, prewritten);
             } else {
                 adjustTransformations(
@@ -158,11 +177,15 @@ public class SinkTransformationTranslator<Input, Output>
                         sink instanceof SupportsConcurrentExecutionAttempts);
             }
 
-            final List<Transformation<?>> sinkTransformations =
-                    executionEnvironment
-                            .getTransformations()
-                            .subList(sizeBefore, executionEnvironment.getTransformations().size());
-            sinkTransformations.forEach(context::transform);
+            getSinkTransformations(sizeBefore).forEach(context::transform);
+
+            repeatUntilConverged(
+                    () ->
+                            getSinkTransformations(sizeBefore).stream()
+                                    .flatMap(t -> context.transform(t).stream())
+                                    .collect(Collectors.toList()));
+
+            disallowUnalignedCheckpoint(getSinkTransformations(sizeBefore));
 
             // Remove all added sink subtransformations to avoid duplications and allow additional
             // expansions
@@ -173,13 +196,121 @@ public class SinkTransformationTranslator<Input, Output>
             }
         }
 
-        private <CommT> void addCommittingTopology(Sink<T> sink, DataStream<T> inputStream) {
-            TwoPhaseCommittingSink<T, CommT> committingSink =
-                    (TwoPhaseCommittingSink<T, CommT>) sink;
-            TypeInformation<CommittableMessage<CommT>> typeInformation =
+        private <R> void repeatUntilConverged(Supplier<R> producer) {
+            R lastResult = producer.get();
+            R nextResult;
+            while (!lastResult.equals(nextResult = producer.get())) {
+                lastResult = nextResult;
+            }
+        }
+
+        private List<Transformation<?>> getSinkTransformations(int sizeBefore) {
+            return executionEnvironment
+                    .getTransformations()
+                    .subList(sizeBefore, executionEnvironment.getTransformations().size());
+        }
+
+        /**
+         * Disables UC for all connections of operators within the sink expansion. This is necessary
+         * because committables need to be at the respective operators on notifyCheckpointComplete
+         * or else we can't commit all side-effects, which violates the contract of
+         * notifyCheckpointComplete.
+         */
+        private void disallowUnalignedCheckpoint(List<Transformation<?>> sinkTransformations) {
+            Optional<Transformation<?>> writerOpt =
+                    sinkTransformations.stream().filter(SinkExpander::isWriter).findFirst();
+            Preconditions.checkState(writerOpt.isPresent(), "Writer transformation not found.");
+            Transformation<?> writer = writerOpt.get();
+            int indexOfWriter = sinkTransformations.indexOf(writer);
+
+            // check all transformation after the writer and recursively disable UC for all inputs
+            // up to the writer
+            Set<Integer> seen = new HashSet<>(writer.getId());
+            Queue<Transformation<?>> pending =
+                    new ArrayDeque<>(
+                            sinkTransformations.subList(
+                                    indexOfWriter + 1, sinkTransformations.size()));
+
+            while (!pending.isEmpty()) {
+                Transformation<?> current = pending.poll();
+                seen.add(current.getId());
+
+                for (Transformation<?> input : current.getInputs()) {
+                    if (input instanceof PartitionTransformation) {
+                        ((PartitionTransformation<?>) input)
+                                .getPartitioner()
+                                .disableUnalignedCheckpoints();
+                    }
+                    if (seen.add(input.getId())) {
+                        pending.add(input);
+                    }
+                }
+            }
+        }
+
+        private static boolean isWriter(Transformation<?> t) {
+            if (!(t instanceof OneInputTransformation)) {
+                return false;
+            }
+            return ((OneInputTransformation<?, ?>) t).getOperatorFactory()
+                    instanceof SinkWriterOperatorFactory;
+        }
+
+        private <CommT, WriteResultT> void addCommittingTopology(
+                Sink<T> sink, DataStream<T> inputStream) {
+            SupportsCommitter<CommT> committingSink = (SupportsCommitter<CommT>) sink;
+            TypeInformation<CommittableMessage<CommT>> committableTypeInformation =
                     CommittableMessageTypeInfo.of(committingSink::getCommittableSerializer);
 
-            DataStream<CommittableMessage<CommT>> written =
+            DataStream<CommittableMessage<CommT>> precommitted;
+            if (sink instanceof SupportsPreCommitTopology) {
+                SupportsPreCommitTopology<WriteResultT, CommT> preCommittingSink =
+                        (SupportsPreCommitTopology<WriteResultT, CommT>) sink;
+                TypeInformation<CommittableMessage<WriteResultT>> writeResultTypeInformation =
+                        CommittableMessageTypeInfo.of(preCommittingSink::getWriteResultSerializer);
+
+                DataStream<CommittableMessage<WriteResultT>> writerResult =
+                        addWriter(sink, inputStream, writeResultTypeInformation);
+
+                precommitted =
+                        adjustTransformations(
+                                writerResult, preCommittingSink::addPreCommitTopology, true, false);
+            } else {
+                precommitted = addWriter(sink, inputStream, committableTypeInformation);
+            }
+
+            DataStream<CommittableMessage<CommT>> committed =
+                    adjustTransformations(
+                            precommitted,
+                            pc ->
+                                    pc.transform(
+                                            COMMITTER_NAME,
+                                            committableTypeInformation,
+                                            new CommitterOperatorFactory<>(
+                                                    committingSink,
+                                                    isBatchMode,
+                                                    isCheckpointingEnabled)),
+                            false,
+                            false);
+
+            if (sink instanceof SupportsPostCommitTopology) {
+                DataStream<CommittableMessage<CommT>> postcommitted = addFailOverRegion(committed);
+                adjustTransformations(
+                        postcommitted,
+                        pc -> {
+                            ((SupportsPostCommitTopology<CommT>) sink).addPostCommitTopology(pc);
+                            return null;
+                        },
+                        true,
+                        false);
+            }
+        }
+
+        private <WriteResultT> DataStream<CommittableMessage<WriteResultT>> addWriter(
+                Sink<T> sink,
+                DataStream<T> inputStream,
+                TypeInformation<CommittableMessage<WriteResultT>> typeInformation) {
+            DataStream<CommittableMessage<WriteResultT>> written =
                     adjustTransformations(
                             inputStream,
                             input ->
@@ -190,42 +321,7 @@ public class SinkTransformationTranslator<Input, Output>
                             false,
                             sink instanceof SupportsConcurrentExecutionAttempts);
 
-            DataStream<CommittableMessage<CommT>> precommitted = addFailOverRegion(written);
-
-            if (sink instanceof WithPreCommitTopology) {
-                precommitted =
-                        adjustTransformations(
-                                precommitted,
-                                ((WithPreCommitTopology<T, CommT>) sink)::addPreCommitTopology,
-                                true,
-                                false);
-            }
-
-            DataStream<CommittableMessage<CommT>> committed =
-                    adjustTransformations(
-                            precommitted,
-                            pc ->
-                                    pc.transform(
-                                            COMMITTER_NAME,
-                                            typeInformation,
-                                            new CommitterOperatorFactory<>(
-                                                    committingSink,
-                                                    isBatchMode,
-                                                    isCheckpointingEnabled)),
-                            false,
-                            false);
-
-            if (sink instanceof WithPostCommitTopology) {
-                DataStream<CommittableMessage<CommT>> postcommitted = addFailOverRegion(committed);
-                adjustTransformations(
-                        postcommitted,
-                        pc -> {
-                            ((WithPostCommitTopology<T, CommT>) sink).addPostCommitTopology(pc);
-                            return null;
-                        },
-                        true,
-                        false);
-            }
+            return addFailOverRegion(written);
         }
 
         /**
@@ -315,6 +411,13 @@ public class SinkTransformationTranslator<Input, Output>
                         Transformation::getDescription,
                         Transformation::setDescription);
 
+                // handle coLocationGroupKey.
+                String coLocationGroupKey = transformation.getCoLocationGroupKey();
+                if (coLocationGroupKey != null
+                        && subTransformation.getCoLocationGroupKey() == null) {
+                    subTransformation.setCoLocationGroupKey(coLocationGroupKey);
+                }
+
                 Optional<SlotSharingGroup> ssg = transformation.getSlotSharingGroup();
 
                 if (ssg.isPresent() && !subTransformation.getSlotSharingGroup().isPresent()) {
@@ -329,7 +432,9 @@ public class SinkTransformationTranslator<Input, Output>
                     // In this case, the subTransformation does not contain any customized
                     // parallelism value and will therefore inherit the parallelism value
                     // from the sinkTransformation.
-                    subTransformation.setParallelism(transformation.getParallelism());
+                    subTransformation.setParallelism(
+                            transformation.getParallelism(),
+                            transformation.isParallelismConfigured());
                 }
 
                 if (subTransformation.getMaxParallelism() < 0
