@@ -32,6 +32,7 @@ import org.apache.flink.runtime.checkpoint.CheckpointMetaData;
 import org.apache.flink.runtime.checkpoint.CheckpointMetrics;
 import org.apache.flink.runtime.checkpoint.CheckpointMetricsBuilder;
 import org.apache.flink.runtime.checkpoint.CheckpointOptions;
+import org.apache.flink.runtime.checkpoint.SubTaskInitializationMetrics;
 import org.apache.flink.runtime.checkpoint.TaskStateSnapshot;
 import org.apache.flink.runtime.checkpoint.channel.ChannelStateWriteRequestExecutorFactory;
 import org.apache.flink.runtime.clusterframework.types.AllocationID;
@@ -98,7 +99,6 @@ import javax.annotation.Nonnull;
 import javax.annotation.Nullable;
 
 import java.io.IOException;
-import java.util.Collection;
 import java.util.Collections;
 import java.util.HashMap;
 import java.util.concurrent.RunnableFuture;
@@ -284,6 +284,10 @@ public class TaskCheckpointingBehaviourTest extends TestLogger {
             declinedLatch.trigger();
         }
 
+        @Override
+        public void reportInitializationMetrics(
+                JobID jobId, SubTaskInitializationMetrics initializationMetrics) {}
+
         public OneShotLatch getDeclinedLatch() {
             return declinedLatch;
         }
@@ -299,17 +303,13 @@ public class TaskCheckpointingBehaviourTest extends TestLogger {
 
         @Override
         public OperatorStateBackend createOperatorStateBackend(
-                Environment env,
-                String operatorIdentifier,
-                @Nonnull Collection<OperatorStateHandle> stateHandles,
-                CloseableRegistry cancelStreamRegistry)
-                throws Exception {
+                OperatorStateBackendParameters parameters) throws Exception {
             return new DefaultOperatorStateBackendBuilder(
-                    env.getUserCodeClassLoader().asClassLoader(),
-                    env.getExecutionConfig(),
+                    parameters.getEnv().getUserCodeClassLoader().asClassLoader(),
+                    parameters.getEnv().getExecutionConfig(),
                     true,
-                    stateHandles,
-                    cancelStreamRegistry) {
+                    parameters.getStateHandles(),
+                    parameters.getCancelStreamRegistry()) {
                 @Override
                 @SuppressWarnings("unchecked")
                 public DefaultOperatorStateBackend build() {
@@ -350,17 +350,13 @@ public class TaskCheckpointingBehaviourTest extends TestLogger {
 
         @Override
         public OperatorStateBackend createOperatorStateBackend(
-                Environment env,
-                String operatorIdentifier,
-                @Nonnull Collection<OperatorStateHandle> stateHandles,
-                CloseableRegistry cancelStreamRegistry)
-                throws Exception {
+                OperatorStateBackendParameters parameters) throws Exception {
             return new DefaultOperatorStateBackendBuilder(
-                    env.getUserCodeClassLoader().asClassLoader(),
-                    env.getExecutionConfig(),
+                    parameters.getEnv().getUserCodeClassLoader().asClassLoader(),
+                    parameters.getEnv().getExecutionConfig(),
                     true,
-                    stateHandles,
-                    cancelStreamRegistry) {
+                    parameters.getStateHandles(),
+                    parameters.getCancelStreamRegistry()) {
                 @Override
                 public DefaultOperatorStateBackend build() {
                     CloseableRegistry registryForStateBackend = new CloseableRegistry();
