@@ -60,6 +60,7 @@ import java.util.HashMap;
 import java.util.LinkedHashMap;
 import java.util.List;
 import java.util.Map;
+import java.util.Objects;
 import java.util.Optional;
 import java.util.Set;
 import java.util.function.Predicate;
@@ -141,6 +142,7 @@ public final class CatalogManager implements CatalogRegistry, AutoCloseable {
     }
 
     /** Builder for a fluent definition of a {@link CatalogManager}. */
+    @Internal
     public static final class Builder {
 
         private @Nullable ClassLoader classLoader;
@@ -200,18 +202,20 @@ public final class CatalogManager implements CatalogRegistry, AutoCloseable {
             checkNotNull(classLoader, "Class loader cannot be null");
             checkNotNull(config, "Config cannot be null");
             checkNotNull(catalogStoreHolder, "CatalogStoreHolder cannot be null");
-            catalogStoreHolder.open();
-            CatalogManager catalogManager =
-                    new CatalogManager(
-                            defaultCatalogName,
-                            defaultCatalog,
-                            dataTypeFactory != null
-                                    ? dataTypeFactory
-                                    : new DataTypeFactoryImpl(classLoader, config, executionConfig),
-                            new ManagedTableListener(classLoader, config),
-                            catalogModificationListeners,
-                            catalogStoreHolder);
-            return catalogManager;
+            return new CatalogManager(
+                    defaultCatalogName,
+                    defaultCatalog,
+                    dataTypeFactory != null
+                            ? dataTypeFactory
+                            : new DataTypeFactoryImpl(
+                                    classLoader,
+                                    config,
+                                    executionConfig == null
+                                            ? null
+                                            : executionConfig.getSerializerConfig()),
+                    new ManagedTableListener(classLoader, config),
+                    catalogModificationListeners,
+                    catalogStoreHolder);
         }
     }
 
@@ -1406,6 +1410,10 @@ public final class CatalogManager implements CatalogRegistry, AutoCloseable {
     public void dropDatabase(
             String catalogName, String databaseName, boolean ignoreIfNotExists, boolean cascade)
             throws DatabaseNotExistException, DatabaseNotEmptyException, CatalogException {
+        if (Objects.equals(currentCatalogName, catalogName)
+                && Objects.equals(currentDatabaseName, databaseName)) {
+            throw new ValidationException("Cannot drop a database which is currently in use.");
+        }
         Catalog catalog = getCatalogOrError(catalogName);
         catalog.dropDatabase(databaseName, ignoreIfNotExists, cascade);
         catalogModificationListeners.forEach(
