@@ -18,6 +18,7 @@
 
 package org.apache.flink.table.operations.ddl;
 
+import org.apache.flink.annotation.Internal;
 import org.apache.flink.table.api.ValidationException;
 import org.apache.flink.table.api.internal.TableResultImpl;
 import org.apache.flink.table.api.internal.TableResultInternal;
@@ -27,6 +28,7 @@ import org.apache.flink.table.catalog.exceptions.TableAlreadyExistException;
 import org.apache.flink.table.catalog.exceptions.TableNotExistException;
 
 /** Operation to describe a ALTER TABLE .. RENAME to .. statement. */
+@Internal
 public class AlterTableRenameOperation extends AlterTableOperation {
     private final ObjectIdentifier newTableIdentifier;
 
