@@ -30,20 +30,20 @@ import org.apache.flink.table.sinks.TableSink;
 import org.apache.flink.table.types.logical.LogicalType;
 import org.apache.flink.types.Row;
 
-import org.junit.Test;
+import org.junit.jupiter.api.TestTemplate;
 
 import java.util.Optional;
 
 /** Tests for verifying name and description of batch sql operator. */
-public class BatchOperatorNameTest extends OperatorNameTestBase {
+class BatchOperatorNameTest extends OperatorNameTestBase {
 
     @Override
     protected TableTestUtil getTableTestUtil() {
         return batchTestUtil(TableConfig.getDefault());
     }
 
-    @Test
-    public void testBoundedStreamScan() {
+    @TestTemplate
+    void testBoundedStreamScan() {
         final DataStream<Integer> dataStream = util.getStreamEnv().fromElements(1, 2, 3, 4, 5);
         TableTestUtil.createTemporaryView(
                 tEnv,
@@ -56,23 +56,23 @@ public class BatchOperatorNameTest extends OperatorNameTestBase {
     }
 
     /** Verify Expand, HashAggregate. */
-    @Test
-    public void testHashAggregate() {
+    @TestTemplate
+    void testHashAggregate() {
         createTestSource();
         verifyQuery("SELECT a, " + "count(distinct b) as b " + "FROM MyTable GROUP BY a");
     }
 
     /** Verify Sort, SortAggregate. */
-    @Test
-    public void testSortAggregate() {
+    @TestTemplate
+    void testSortAggregate() {
         tEnv.getConfig().set(ExecutionConfigOptions.TABLE_EXEC_DISABLED_OPERATORS, "HashAgg");
         createTestSource();
         verifyQuery("SELECT a, " + "count(distinct b) as b " + "FROM MyTable GROUP BY a");
     }
 
     /** Verify SortWindowAggregate. */
-    @Test
-    public void testSortWindowAggregate() {
+    @TestTemplate
+    void testSortWindowAggregate() {
         createSourceWithTimeAttribute();
         verifyQuery(
                 "SELECT\n"
@@ -84,14 +84,14 @@ public class BatchOperatorNameTest extends OperatorNameTestBase {
     }
 
     /** Verify HashJoin. */
-    @Test
-    public void testHashJoin() {
+    @TestTemplate
+    void testHashJoin() {
         testJoinInternal();
     }
 
     /** Verify NestedLoopJoin. */
-    @Test
-    public void testNestedLoopJoin() {
+    @TestTemplate
+    void testNestedLoopJoin() {
         tEnv.getConfig()
                 .set(
                         ExecutionConfigOptions.TABLE_EXEC_DISABLED_OPERATORS,
@@ -100,8 +100,8 @@ public class BatchOperatorNameTest extends OperatorNameTestBase {
     }
 
     /** Verify SortMergeJoin. */
-    @Test
-    public void testSortMergeJoin() {
+    @TestTemplate
+    void testSortMergeJoin() {
         tEnv.getConfig()
                 .set(
                         ExecutionConfigOptions.TABLE_EXEC_DISABLED_OPERATORS,
@@ -110,8 +110,8 @@ public class BatchOperatorNameTest extends OperatorNameTestBase {
     }
 
     /** Verify MultiInput. */
-    @Test
-    public void testMultiInput() {
+    @TestTemplate
+    void testMultiInput() {
         createTestSource("A");
         createTestSource("B");
         createTestSource("C");
@@ -119,21 +119,21 @@ public class BatchOperatorNameTest extends OperatorNameTestBase {
     }
 
     /** Verify Limit. */
-    @Test
-    public void testLimit() {
+    @TestTemplate
+    void testLimit() {
         createTestSource();
         verifyQuery("select * from MyTable limit 10");
     }
 
     /** Verify SortLimit. */
-    @Test
-    public void testSortLimit() {
+    @TestTemplate
+    void testSortLimit() {
         createTestSource();
         verifyQuery("select * from MyTable order by a limit 10");
     }
 
-    @Test
-    public void testLegacySourceSink() {
+    @TestTemplate
+    void testLegacySourceSink() {
         TableSchema schema = TestLegacyFilterableTableSource.defaultSchema();
         TestLegacyFilterableTableSource.createTemporaryTable(
                 tEnv,
@@ -153,8 +153,8 @@ public class BatchOperatorNameTest extends OperatorNameTestBase {
         verifyInsert("insert into MySink select * from MySource");
     }
 
-    @Test
-    public void testMatch() {
+    @TestTemplate
+    void testMatch() {
         createSourceWithTimeAttribute();
         String sql =
                 "SELECT T.aid, T.bid, T.cid\n"
