@@ -28,16 +28,15 @@ import org.apache.flink.table.planner.runtime.utils.StreamingWithStateTestBase.{
 import org.apache.flink.table.planner.runtime.utils.TestData
 import org.apache.flink.table.runtime.util.RowDataHarnessAssertor
 import org.apache.flink.table.runtime.util.StreamRecordUtils.binaryRecord
+import org.apache.flink.testutils.junit.extensions.parameterized.{ParameterizedTestExtension, Parameters}
 import org.apache.flink.types.Row
 import org.apache.flink.types.RowKind.INSERT
 
-import org.junit.{Before, Test}
-import org.junit.runner.RunWith
-import org.junit.runners.Parameterized
+import org.junit.jupiter.api.{BeforeEach, TestTemplate}
+import org.junit.jupiter.api.extension.ExtendWith
 
 import java.time.{LocalDateTime, ZoneId}
-import java.util.{Collection => JCollection}
-import java.util.TimeZone
+import java.util.{Collection => JCollection, TimeZone}
 import java.util.concurrent.ConcurrentLinkedQueue
 
 import scala.collection.JavaConversions._
@@ -47,11 +46,11 @@ import scala.collection.JavaConversions._
  * them in [[WindowAggregateITCase]] because the result is non-deterministic, therefore we use
  * harness to test them.
  */
-@RunWith(classOf[Parameterized])
+@ExtendWith(Array(classOf[ParameterizedTestExtension]))
 class WindowAggregateUseDaylightTimeHarnessTest(backend: StateBackendMode, timeZone: TimeZone)
   extends HarnessTestBase(backend) {
 
-  @Before
+  @BeforeEach
   override def before(): Unit = {
     super.before()
     val dataId = TestValuesTableFactory.registerData(TestData.windowDataWithTimestamp)
@@ -73,7 +72,7 @@ class WindowAggregateUseDaylightTimeHarnessTest(backend: StateBackendMode, timeZ
                        |""".stripMargin)
   }
 
-  @Test
+  @TestTemplate
   def testProcessingTimeWindow(): Unit = {
     val sql =
       """
@@ -93,7 +92,7 @@ class WindowAggregateUseDaylightTimeHarnessTest(backend: StateBackendMode, timeZ
         |GROUP BY `name`, window_start, window_end
       """.stripMargin
     val t1 = tEnv.sqlQuery(sql)
-    val testHarness = createHarnessTester(t1.toAppendStream[Row], "WindowAggregate")
+    val testHarness = createHarnessTester(t1.toDataStream, "WindowAggregate")
     // window aggregate put window properties at the end of aggs
     val assertor = new RowDataHarnessAssertor(
       Array(
@@ -203,7 +202,7 @@ class WindowAggregateUseDaylightTimeHarnessTest(backend: StateBackendMode, timeZ
 
 object WindowAggregateUseDaylightTimeHarnessTest {
 
-  @Parameterized.Parameters(name = "StateBackend={0}, TimeZone={1}")
+  @Parameters(name = "StateBackend={0}, TimeZone={1}")
   def parameters(): JCollection[Array[Object]] = {
     Seq[Array[AnyRef]](
       Array(HEAP_BACKEND, TimeZone.getTimeZone("America/Los_Angeles")),
