@@ -21,29 +21,113 @@ import org.apache.flink.api.common.time.Time
 import org.apache.flink.api.scala._
 import org.apache.flink.table.api._
 import org.apache.flink.table.api.bridge.scala._
-import org.apache.flink.table.planner.runtime.utils.{StreamingWithStateTestBase, TestingRetractSink}
+import org.apache.flink.table.planner.factories.TestValuesTableFactory
+import org.apache.flink.table.planner.runtime.utils.{JavaUserDefinedTableAggFunctions, StreamingWithStateTestBase, TestData, TestingRetractSink}
 import org.apache.flink.table.planner.runtime.utils.JavaUserDefinedAggFunctions.OverloadedDoubleMaxFunction
 import org.apache.flink.table.planner.runtime.utils.StreamingWithStateTestBase.StateBackendMode
 import org.apache.flink.table.planner.runtime.utils.TestData.tupleData3
 import org.apache.flink.table.planner.utils.{TableAggSum, Top3, Top3Accum, Top3WithMapView, Top3WithRetractInput}
+import org.apache.flink.testutils.junit.extensions.parameterized.ParameterizedTestExtension
 import org.apache.flink.types.Row
 
-import org.junit.{Before, Test}
-import org.junit.Assert.assertEquals
-import org.junit.runner.RunWith
-import org.junit.runners.Parameterized
+import org.assertj.core.api.Assertions.{assertThat, assertThatThrownBy}
+import org.junit.jupiter.api.{BeforeEach, TestTemplate}
+import org.junit.jupiter.api.extension.ExtendWith
+
+import java.time.Duration
 
 /** Tests of groupby (without window) table aggregations */
-@RunWith(classOf[Parameterized])
+@ExtendWith(Array(classOf[ParameterizedTestExtension]))
 class TableAggregateITCase(mode: StateBackendMode) extends StreamingWithStateTestBase(mode) {
 
-  @Before
+  @BeforeEach
   override def before(): Unit = {
     super.before()
-    tEnv.getConfig.setIdleStateRetentionTime(Time.hours(1), Time.hours(2))
+    tEnv.getConfig.setIdleStateRetention(Duration.ofHours(1))
+    // Create a Table from the array of Rows
+    tEnv.executeSql(s"""
+                       |CREATE TABLE myTable (
+                       |  `id` INT,
+                       |  `name` STRING,
+                       |  `price` INT
+                       |) WITH (
+                       |  'connector' = 'values',
+                       |  'data-id' = '${TestValuesTableFactory.registerData(TestData.tupleData4)}'
+                       |)
+                       |""".stripMargin)
   }
 
-  @Test
+  @TestTemplate
+  def testFlatAggregateWithoutIncrementalUpdate(): Unit = {
+    // Register the table aggregate function which does not implement emitUpdateWithRetract
+    tEnv.createTemporarySystemFunction("top2", new JavaUserDefinedTableAggFunctions.Top2)
+
+    checkRank(
+      "top2",
+      List(
+        // output triggered by (1, "Latte", 6)
+        "(true,6,1)",
+        // output triggered by (2, "Milk", 3)
+        "(false,6,1)",
+        "(true,6,1)",
+        "(true,3,2)",
+        // output triggered by (3, "Breve", 5)
+        "(false,6,1)",
+        "(false,3,2)",
+        "(true,6,1)",
+        "(true,5,2)",
+        // output triggered by (4, "Mocha", 8)
+        "(false,6,1)",
+        "(false,5,2)",
+        "(true,8,1)",
+        "(true,6,2)",
+        // output triggered by (5, "Tea", 4)
+        "(false,8,1)",
+        "(false,6,2)",
+        "(true,8,1)",
+        "(true,6,2)"
+      )
+    )
+  }
+
+  @TestTemplate
+  def testFlatAggregateWithIncrementalUpdate(): Unit = {
+    tEnv.createTemporarySystemFunction(
+      "incrementalTop2",
+      new JavaUserDefinedTableAggFunctions.IncrementalTop2)
+    checkRank(
+      "incrementalTop2",
+      List(
+        // output triggered by (1, "Latte", 6)
+        "(true,6,1)",
+        // output triggered by (2, "Milk", 3)
+        "(true,3,2)",
+        // output triggered by (3, "Breve", 5)
+        "(false,3,2)",
+        "(true,5,2)",
+        // output triggered by (4, "Mocha", 8)
+        "(false,6,1)",
+        "(true,8,1)",
+        "(false,5,2)",
+        "(true,6,2)"
+      )
+    )
+  }
+
+  def checkRank(func: String, expectedResult: List[String]): Unit = {
+    val resultTable =
+      tEnv
+        .from("myTable")
+        .flatAggregate(call(func, $("price")).as("top_price", "rank"))
+        .select($("top_price"), $("rank"))
+
+    val sink = new TestingRetractSink()
+    resultTable.toRetractStream[Row].addSink(sink).setParallelism(1)
+    env.execute()
+    assertThat(sink.getRawResults).isEqualTo(expectedResult)
+  }
+
+  @TestTemplate
   def testGroupByFlatAggregate(): Unit = {
     val top3 = new Top3
 
@@ -75,10 +159,10 @@ class TableAggregateITCase(mode: StateBackendMode) extends StreamingWithStateTes
       "6,20,20",
       "6,19,19"
     ).sorted
-    assertEquals(expected, sink.getRetractResults.sorted)
+    assertThat(sink.getRetractResults.sorted).isEqualTo(expected)
   }
 
-  @Test
+  @TestTemplate
   def testNonkeyedFlatAggregate(): Unit = {
 
     val top3 = new Top3
@@ -97,10 +181,10 @@ class TableAggregateITCase(mode: StateBackendMode) extends StreamingWithStateTes
       "20,20",
       "21,21"
     ).sorted
-    assertEquals(expected, sink.getRetractResults.sorted)
+    assertThat(sink.getRetractResults.sorted).isEqualTo(expected)
   }
 
-  @Test
+  @TestTemplate
   def testAggregateAfterTableAggregate(): Unit = {
     val top3 = new Top3
 
@@ -125,10 +209,10 @@ class TableAggregateITCase(mode: StateBackendMode) extends StreamingWithStateTes
       "5,15",
       "6,21"
     ).sorted
-    assertEquals(expected, sink.getRetractResults.sorted)
+    assertThat(sink.getRetractResults.sorted).isEqualTo(expected)
   }
 
-  @Test
+  @TestTemplate
   def testGroupByFlatAggregateWithMapView(): Unit = {
     val top3 = new Top3WithMapView
 
@@ -160,10 +244,10 @@ class TableAggregateITCase(mode: StateBackendMode) extends StreamingWithStateTes
       "6,20,20",
       "6,19,19"
     ).sorted
-    assertEquals(expected, sink.getRetractResults.sorted)
+    assertThat(sink.getRetractResults.sorted).isEqualTo(expected)
   }
 
-  @Test
+  @TestTemplate
   def testInputWithRetraction(): Unit = {
 
     val top3 = new Top3WithRetractInput
@@ -183,10 +267,10 @@ class TableAggregateITCase(mode: StateBackendMode) extends StreamingWithStateTes
       "65,65",
       "34,34"
     ).sorted
-    assertEquals(expected, sink.getRetractResults.sorted)
+    assertThat(sink.getRetractResults.sorted).isEqualTo(expected)
   }
 
-  @Test
+  @TestTemplate
   def testInternalAccumulatorType(): Unit = {
     val source = failingDataSource(tupleData3).toTable(tEnv, 'a, 'b, 'c)
     val resultTable = source
@@ -211,30 +295,33 @@ class TableAggregateITCase(mode: StateBackendMode) extends StreamingWithStateTes
       "2,5",
       "1,1",
       "1,1").sorted
-    assertEquals(expected, sink.getRetractResults.sorted)
+    assertThat(sink.getRetractResults.sorted).isEqualTo(expected)
   }
 
-  @Test
+  @TestTemplate
   def testTableAggFunctionWithoutRetractionMethod(): Unit = {
-    expectedException.expect(classOf[ValidationException])
-    expectedException.expectMessage(
-      s"Could not find an implementation method 'retract' in class '${classOf[Top3].getName}' " +
-        s"for function 'Top3' that matches the following signature:\n" +
-        s"void retract(${classOf[Top3Accum].getName}, java.lang.Integer)")
-
     val top3 = new Top3
     val source = env.fromCollection(tupleData3).toTable(tEnv, 'a, 'b, 'c)
-    source
-      .groupBy('b)
-      .select('b, 'a.sum.as('a))
-      .flatAggregate(top3('a).as('v1, 'v2))
-      .select('v1, 'v2)
-      .toRetractStream[Row]
 
-    env.execute()
+    assertThatThrownBy(
+      () => {
+        source
+          .groupBy('b)
+          .select('b, 'a.sum.as('a))
+          .flatAggregate(top3('a).as('v1, 'v2))
+          .select('v1, 'v2)
+          .toRetractStream[Row]
+
+        env.execute()
+      })
+      .hasMessage(
+        s"Could not find an implementation method 'retract' in class '${classOf[Top3].getName}' " +
+          s"for function 'Top3' that matches the following signature:\n" +
+          s"void retract(${classOf[Top3Accum].getName}, java.lang.Integer)")
+      .isInstanceOf[ValidationException]
   }
 
-  @Test
+  @TestTemplate
   def testOverloadedAccumulator(): Unit = {
     val source = failingDataSource(tupleData3).toTable(tEnv, 'a, 'b, 'c)
 
@@ -273,7 +360,7 @@ class TableAggregateITCase(mode: StateBackendMode) extends StreamingWithStateTes
       "6,21",
       "6,21"
     )
-    assertEquals(expected1.sorted, sink1.getRetractResults.sorted)
+    assertThat(sink1.getRetractResults.sorted).isEqualTo(expected1.sorted)
 
     val expected2 = List(
       "1,1str",
@@ -289,6 +376,6 @@ class TableAggregateITCase(mode: StateBackendMode) extends StreamingWithStateTes
       "6,21str",
       "6,21str"
     )
-    assertEquals(expected2.sorted, sink2.getRetractResults.sorted)
+    assertThat(sink2.getRetractResults.sorted).isEqualTo(expected2.sorted)
   }
 }
