@@ -37,12 +37,13 @@ import org.apache.flink.table.types.logical.RowType;
 import org.apache.flink.table.types.logical.SmallIntType;
 import org.apache.flink.table.types.logical.VarCharType;
 
-import org.junit.Assert;
 import org.junit.Test;
 
 import java.util.Iterator;
 import java.util.Random;
 
+import static org.assertj.core.api.Assertions.assertThat;
+
 /** Base test class for {@link BytesMultiMap} and {@link WindowBytesMultiMap}. */
 public abstract class BytesMultiMapTestBase<K> extends BytesMapTestBase {
     protected static final int NUM_VALUE_PER_KEY = 50;
@@ -121,7 +122,7 @@ public abstract class BytesMultiMapTestBase<K> extends BytesMapTestBase {
             int i = 0;
             Iterator<RowData> valueIter = iter.getValue();
             while (valueIter.hasNext()) {
-                Assert.assertEquals(valueIter.next(), values[i++]);
+                assertThat(values[i++]).isEqualTo(valueIter.next());
             }
         }
     }
